@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2009/02/17 02:48:46 $
+ * $Revision: 1.3 $
+ * $Date: 2010/12/01 22:51:32 $
  * -----------------------------------------------------------------
  * Programmer(s): Scott D. Cohen, Alan C. Hindmarsh and
  *                Radu Serban @ LLNL
@@ -74,7 +74,7 @@
  * but there should be no such messages.
  *
  * Note: This program requires the dense linear solver functions
- * newDenseMat, newIntArray, denseAddIdentity, denseGETRF, denseGETRS, 
+ * newDenseMat, newLintArray, denseAddIdentity, denseGETRF, denseGETRS, 
  * destroyMat and destroyArray.
  *
  * Note: This program assumes the sequential implementation for the
@@ -160,7 +160,7 @@
 
 typedef struct {
   realtype **P[NGRP];
-  int *pivot[NGRP];
+  long int *pivot[NGRP];
   int ns, mxns;
   int mp, mq, mx, my, ngrp, ngx, ngy, mxmp;
   int jgx[NGX+1], jgy[NGY+1], jigx[MX], jigy[MY];
@@ -324,13 +324,13 @@ int main()
 static WebData AllocUserData(void)
 {
   int i, ngrp = NGRP;
-  int ns = NS;
+  long int ns = NS;
   WebData wdata;
   
   wdata = (WebData) malloc(sizeof *wdata);
   for(i=0; i < ngrp; i++) {
     (wdata->P)[i] = newDenseMat(ns, ns);
-    (wdata->pivot)[i] = newIntArray(ns);
+    (wdata->pivot)[i] = newLintArray(ns);
   }
   wdata->rewt = N_VNew_Serial(NEQ);
   return(wdata);
@@ -750,9 +750,11 @@ static int Precond(realtype t, N_Vector c, N_Vector fc,
                    N_Vector vtemp3)
 {
   realtype ***P;
-  int **pivot, ier;
+  int ier;
+  long int **pivot;
   int i, if0, if00, ig, igx, igy, j, jj, jx, jy;
-  int *jxr, *jyr, mp, ngrp, ngx, ngy, mxmp, flag;
+  int *jxr, *jyr, ngrp, ngx, ngy, mxmp, flag;
+  long int mp;
   realtype uround, fac, r, r0, save, srur;
   realtype *f1, *fsave, *cdata, *rewtdata;
   WebData wdata;
@@ -861,8 +863,9 @@ static int PSolve(realtype tn, N_Vector c, N_Vector fc,
                   int lr, void *user_data, N_Vector vtemp)
 {
   realtype   ***P;
-  int **pivot;
-  int jx, jy, igx, igy, iv, ig, *jigx, *jigy, mx, my, ngx, mp;
+  long int **pivot;
+  int jx, jy, igx, igy, iv, ig, *jigx, *jigy, mx, my, ngx;
+  long int mp;
   WebData wdata;
   
   wdata = (WebData) user_data;
