@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2009/02/17 02:48:46 $
+ * $Revision: 1.4 $
+ * $Date: 2011/11/23 23:53:02 $
  * -----------------------------------------------------------------
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -144,7 +144,7 @@
 
 typedef struct {
   realtype **P[NGRP];
-  int *pivot[NGRP];
+  long int *pivot[NGRP];
   int ns,  mxns, mp, mq, mx, my, ngrp, ngx, ngy, mxmp;
   int jgx[NGX+1], jgy[NGY+1], jigx[MX], jigy[MY];
   int jxr[NGX], jyr[NGY];
@@ -286,6 +286,9 @@ int main(int argc, char *argv[])
   flag = CVodeF(cvode_mem, TOUT, c, &t, CV_NORMAL, &ncheck);
   if(check_flag(&flag, "CVodeF", 1)) return(1);
 
+  printf("\nncheck = %d\n", ncheck);
+
+
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("\n   G = int_t int_x int_y c%d(t,x,y) dx dy dt = %Lf \n\n", 
          ISPEC, NV_DATA_S(c)[NEQ]);
@@ -432,9 +435,10 @@ static int Precond(realtype t, N_Vector c, N_Vector fc,
 {
   int N;
   realtype ***P;
-  int **pivot, ier;
+  long int **pivot, ier;
   int i, if0, if00, ig, igx, igy, j, jj, jx, jy;
-  int *jxr, *jyr, mp, ngrp, ngx, ngy, mxmp, flag;
+  int *jxr, *jyr, ngrp, ngx, ngy, mxmp, flag;
+  long int mp;
   realtype uround, fac, r, r0, save, srur;
   realtype *f1, *fsave, *cdata, *rewtdata;
   void *cvode_mem;
@@ -528,8 +532,9 @@ static int PSolve(realtype t, N_Vector c, N_Vector fc,
                   int lr, void *user_data, N_Vector vtemp)
 {
   realtype ***P;
-  int **pivot;
-  int jx, jy, igx, igy, iv, ig, *jigx, *jigy, mx, my, ngx, mp;
+  long int **pivot;
+  int jx, jy, igx, igy, iv, ig, *jigx, *jigy, mx, my, ngx;
+  long int mp;
   WebData wdata;
 
   wdata = (WebData) user_data;
@@ -647,9 +652,10 @@ static int PrecondB(realtype t, N_Vector c,
 {
   int N;
   realtype ***P;
-  int **pivot, ier;
+  long int **pivot, ier;
   int i, if0, if00, ig, igx, igy, j, jj, jx, jy;
-  int *jxr, *jyr, mp, ngrp, ngx, ngy, mxmp, flag;
+  int *jxr, *jyr, ngrp, ngx, ngy, mxmp, flag;
+  long int mp;
   realtype uround, fac, r, r0, save, srur;
   realtype *f1, *fsave, *cdata, *rewtdata;
   void *cvode_mem;
@@ -737,8 +743,9 @@ static int PSolveB(realtype t, N_Vector c,
                    int lr, void *user_data, N_Vector vtemp)
 {
   realtype ***P;
-  int **pivot;
-  int jx, jy, igx, igy, iv, ig, *jigx, *jigy, mx, my, ngx, mp;
+  long int **pivot;
+  int jx, jy, igx, igy, iv, ig, *jigx, *jigy, mx, my, ngx;
+  long int mp;
   WebData wdata;
 
   wdata = (WebData) user_data;
@@ -792,7 +799,7 @@ static WebData AllocUserData(void)
   wdata = (WebData) malloc(sizeof *wdata);
   for(i=0; i < ngrp; i++) {
     (wdata->P)[i] = newDenseMat(ns, ns);
-    (wdata->pivot)[i] = newIntArray(ns);
+    (wdata->pivot)[i] = newLintArray(ns);
   }
   wdata->rewt = N_VNew_Serial(NEQ+1);
   return(wdata);
