@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2009/01/14 19:55:22 $
+ * $Revision: 1.4 $
+ * $Date: 2011/11/23 23:53:02 $
  * ----------------------------------------------------------------- 
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -101,7 +101,7 @@ typedef struct {
 /* Prototypes of user-supplied functions */
 
 static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data);
-static int Jac(int N, realtype t,
+static int Jac(long int N, realtype t,
                N_Vector y, N_Vector fy, 
                DlsMat J, void *user_data, 
                N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
@@ -110,7 +110,7 @@ static int ewt(N_Vector y, N_Vector w, void *user_data);
 
 static int fB(realtype t, N_Vector y, 
               N_Vector yB, N_Vector yBdot, void *user_dataB);
-static int JacB(int NB, realtype t,
+static int JacB(long int NB, realtype t,
                 N_Vector y, N_Vector yB, N_Vector fyB,
                 DlsMat JB, void *user_dataB,
                 N_Vector tmp1B, N_Vector tmp2B, N_Vector tmp3B);
@@ -238,6 +238,7 @@ int main(int argc, char *argv[])
   if (check_flag(&flag, "CVodeGetNumSteps", 1)) return(1);
 
   printf("done ( nst = %ld )\n",nst);
+  printf("\nncheck = %d\n\n", ncheck);
 
   flag = CVodeGetQuad(cvode_mem, &time, q);
   if (check_flag(&flag, "CVodeGetQuad", 1)) return(1);
@@ -424,7 +425,7 @@ static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data)
  * Jacobian routine. Compute J(t,y). 
 */
 
-static int Jac(int N, realtype t,
+static int Jac(long int N, realtype t,
                N_Vector y, N_Vector fy, 
                DlsMat J, void *user_data, 
                N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
@@ -519,7 +520,7 @@ static int fB(realtype t, N_Vector y, N_Vector yB, N_Vector yBdot, void *user_da
  * JacB routine. Compute JB(t,y,yB). 
 */
 
-static int JacB(int NB, realtype t,
+static int JacB(long int NB, realtype t,
                 N_Vector y, N_Vector yB, N_Vector fyB,
                 DlsMat JB, void *user_dataB,
                 N_Vector tmp1B, N_Vector tmp2B, N_Vector tmp3B)
