@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.8 $
- * $Date: 2008/04/18 19:42:38 $
+ * $Revision: 1.9 $
+ * $Date: 2010/12/01 22:15:15 $
  * ----------------------------------------------------------------- 
  * Programmer: Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -144,7 +144,7 @@ extern "C" {
  */
   
   
-typedef int (*IDADlsDenseJacFn)(int N, realtype t, realtype c_j,
+typedef int (*IDADlsDenseJacFn)(long int N, realtype t, realtype c_j,
 				N_Vector y, N_Vector yp, N_Vector r, 
 				DlsMat Jac, void *user_data,
 				N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
@@ -232,7 +232,7 @@ typedef int (*IDADlsDenseJacFn)(int N, realtype t, realtype c_j,
  * -----------------------------------------------------------------
  */
 
-typedef int (*IDADlsBandJacFn)(int N, int mupper, int mlower,
+typedef int (*IDADlsBandJacFn)(long int N, long int mupper, long int mlower,
 			       realtype t, realtype c_j, 
 			       N_Vector y, N_Vector yp, N_Vector r,
 			       DlsMat Jac, void *user_data,
@@ -292,7 +292,7 @@ SUNDIALS_EXPORT int IDADlsSetBandJacFn(void *ida_mem, IDADlsBandJacFn jac);
 SUNDIALS_EXPORT int IDADlsGetWorkSpace(void *ida_mem, long int *lenrwLS, long int *leniwLS);
 SUNDIALS_EXPORT int IDADlsGetNumJacEvals(void *ida_mem, long int *njevals);
 SUNDIALS_EXPORT int IDADlsGetNumResEvals(void *ida_mem, long int *nfevalsLS);
-SUNDIALS_EXPORT int IDADlsGetLastFlag(void *ida_mem, int *flag);
+SUNDIALS_EXPORT int IDADlsGetLastFlag(void *ida_mem, long int *flag);
 
 /*
  * -----------------------------------------------------------------
@@ -301,7 +301,7 @@ SUNDIALS_EXPORT int IDADlsGetLastFlag(void *ida_mem, int *flag);
  * -----------------------------------------------------------------
  */
 
-SUNDIALS_EXPORT char *IDADlsGetReturnFlagName(int flag);
+SUNDIALS_EXPORT char *IDADlsGetReturnFlagName(long int flag);
 
 /*
  * =================================================================
@@ -324,7 +324,7 @@ SUNDIALS_EXPORT char *IDADlsGetReturnFlagName(int flag);
  * -----------------------------------------------------------------
  */
 
-typedef int (*IDADlsDenseJacFnB)(int NeqB, realtype tt, realtype c_jB, 
+typedef int (*IDADlsDenseJacFnB)(long int NeqB, realtype tt, realtype c_jB, 
 				 N_Vector yy, N_Vector yp,
 				 N_Vector yyB, N_Vector ypB, N_Vector rrB,
 				 DlsMat JacB, void *user_dataB, 
@@ -340,7 +340,7 @@ typedef int (*IDADlsDenseJacFnB)(int NeqB, realtype tt, realtype c_jB,
  * -----------------------------------------------------------------
  */
 
-typedef int (*IDADlsBandJacFnB)(int NeqB, int mupperB, int mlowerB, 
+typedef int (*IDADlsBandJacFnB)(long int NeqB, long int mupperB, long int mlowerB, 
 				realtype tt, realtype c_jB, 
 				N_Vector yy, N_Vector yp,
 				N_Vector yyB, N_Vector ypB, N_Vector rrB,
