@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.4 $
- * $Date: 2008/04/18 19:42:38 $
+ * $Revision: 1.5 $
+ * $Date: 2010/12/01 22:16:17 $
  * -----------------------------------------------------------------
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -45,7 +45,7 @@ extern "C" {
  * -----------------------------------------------------------------
  */
 
-SUNDIALS_EXPORT int KINDense(void *kinmem, int N);
+SUNDIALS_EXPORT int KINDense(void *kinmem, long int N);
 
 #endif
 
