@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.7 $
- * $Date: 2009/02/17 02:42:29 $
+ * $Revision: 1.8 $
+ * $Date: 2010/12/01 22:21:04 $
  * ----------------------------------------------------------------- 
  * Programmer(s): Scott D. Cohen, Alan C. Hindmarsh, Radu Serban,
  *                and Aaron Collier @ LLNL
@@ -71,12 +71,12 @@ static int CVBandPDQJac(CVBandPrecData pdata,
  * -----------------------------------------------------------------
  */
 
-int CVBandPrecInit(void *cvode_mem, int N, int mu, int ml)
+int CVBandPrecInit(void *cvode_mem, long int N, long int mu, long int ml)
 {
   CVodeMem cv_mem;
   CVSpilsMem cvspils_mem;
   CVBandPrecData pdata;
-  int mup, mlp, storagemu;
+  long int mup, mlp, storagemu;
   int flag;
 
   if (cvode_mem == NULL) {
@@ -135,9 +135,9 @@ int CVBandPrecInit(void *cvode_mem, int N, int mu, int ml)
   }
 
   /* Allocate memory for pivot array. */
-  pdata->pivots = NULL;
-  pdata->pivots = NewIntArray(N);
-  if (pdata->savedJ == NULL) {
+  pdata->lpivots = NULL;
+  pdata->lpivots = NewLintArray(N);
+  if (pdata->lpivots == NULL) {
     DestroyMat(pdata->savedP);
     DestroyMat(pdata->savedJ);
     free(pdata); pdata = NULL;
@@ -162,7 +162,7 @@ int CVBandPrecGetWorkSpace(void *cvode_mem, long int *lenrwBP, long int *leniwBP
   CVodeMem cv_mem;
   CVSpilsMem cvspils_mem;
   CVBandPrecData pdata;
-  int N, ml, mu, smu;
+  long int N, ml, mu, smu;
 
   
   if (cvode_mem == NULL) {
@@ -225,13 +225,13 @@ int CVBandPrecGetNumRhsEvals(void *cvode_mem, long int *nfevalsBP)
 
 /* Readability Replacements */
 
-#define N      (pdata->N)
-#define mu     (pdata->mu)
-#define ml     (pdata->ml)
-#define pivots (pdata->pivots)
-#define savedJ (pdata->savedJ)
-#define savedP (pdata->savedP)
-#define nfeBP  (pdata->nfeBP)
+#define N       (pdata->N)
+#define mu      (pdata->mu)
+#define ml      (pdata->ml)
+#define lpivots (pdata->lpivots)
+#define savedJ  (pdata->savedJ)
+#define savedP  (pdata->savedP)
+#define nfeBP   (pdata->nfeBP)
 
 /*
  * -----------------------------------------------------------------
@@ -289,8 +289,9 @@ static int CVBandPrecSetup(realtype t, N_Vector y, N_Vector fy,
   CVBandPrecData pdata;
   CVodeMem cv_mem;
   int retval;
+  long int ier;
 
-  /* Assume matrix and pivots have already been allocated. */
+  /* Assume matrix and lpivots have already been allocated. */
   pdata = (CVBandPrecData) bp_data;
 
   cv_mem = (CVodeMem) pdata->cvode_mem;
@@ -325,10 +326,10 @@ static int CVBandPrecSetup(realtype t, N_Vector y, N_Vector fy,
   AddIdentity(savedP);
  
   /* Do LU factorization of matrix. */
-  retval = BandGBTRF(savedP, pivots);
+  ier = BandGBTRF(savedP, lpivots);
  
   /* Return 0 if the LU was complete; otherwise return 1. */
-  if (retval > 0) return(1);
+  if (ier > 0) return(1);
   return(0);
 }
 
@@ -360,7 +361,7 @@ static int CVBandPrecSolve(realtype t, N_Vector y, N_Vector fy,
   CVBandPrecData pdata;
   realtype *zd;
 
-  /* Assume matrix and pivots have already been allocated. */
+  /* Assume matrix and lpivots have already been allocated. */
   pdata = (CVBandPrecData) bp_data;
 
   /* Copy r to z. */
@@ -369,7 +370,7 @@ static int CVBandPrecSolve(realtype t, N_Vector y, N_Vector fy,
   /* Do band backsolve on the vector z. */
   zd = N_VGetArrayPointer(z);
 
-  BandGBTRS(savedP, pivots, zd);
+  BandGBTRS(savedP, lpivots, zd);
 
   return(0);
 }
@@ -388,7 +389,7 @@ static void CVBandPrecFree(CVodeMem cv_mem)
 
   DestroyMat(savedJ);
   DestroyMat(savedP);
-  DestroyArray(pivots);
+  DestroyArray(lpivots);
 
   free(pdata);
   pdata = NULL;
@@ -419,7 +420,7 @@ static int CVBandPDQJac(CVBandPrecData pdata,
 {
   CVodeMem cv_mem;
   realtype fnorm, minInc, inc, inc_inv, srur;
-  int group, i, j, width, ngroups, i1, i2;
+  long int group, i, j, width, ngroups, i1, i2;
   realtype *col_j, *ewt_data, *fy_data, *ftemp_data, *y_data, *ytemp_data;
   int retval;
 
