@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.8 $
- * $Date: 2009/02/17 02:42:29 $
+ * $Revision: 1.15 $
+ * $Date: 2011/03/23 22:45:54 $
  * ----------------------------------------------------------------- 
  * Programmer: Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -128,7 +128,7 @@ static void cvLapackBandFree(CVodeMem cv_mem);
  * (*cvode_mem) to the address of this structure.  It sets setupNonNull 
  * in (*cvode_mem) to TRUE, and the d_jac field to the default 
  * cvDlsDenseDQJac. Finally, it allocates memory for M, pivots, and 
- * (if needed) savedJ.
+ * savedJ.
  * The return value is SUCCESS = 0, or LMEM_FAIL = -1.
  *
  * NOTE: The dense linear solver assumes a serial implementation
@@ -185,32 +185,32 @@ int CVLapackDense(void *cvode_mem, int N)
   setupNonNull = TRUE;
 
   /* Set problem dimension */
-  n = N;
+  n = (long int) N;
 
-  /* Allocate memory for M, pivot array, and (if needed) savedJ */
+  /* Allocate memory for M, pivot array, and savedJ */
   M = NULL;
   pivots = NULL;
   savedJ = NULL;
 
-  M = NewDenseMat(N, N);
+  M = NewDenseMat(n, n);
   if (M == NULL) {
     CVProcessError(cv_mem, CVDLS_MEM_FAIL, "CVLAPACK", "CVLapackDense", MSGD_MEM_FAIL);
-    free(cvdls_mem);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_MEM_FAIL);
   }
   pivots = NewIntArray(N);
   if (pivots == NULL) {
     CVProcessError(cv_mem, CVDLS_MEM_FAIL, "CVLAPACK", "CVLapackDense", MSGD_MEM_FAIL);
     DestroyMat(M);
-    free(cvdls_mem);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_MEM_FAIL);
   }
-  savedJ = NewDenseMat(N, N);
+  savedJ = NewDenseMat(n, n);
   if (savedJ == NULL) {
     CVProcessError(cv_mem, CVDLS_MEM_FAIL, "CVLAPACK", "CVLapackDense", MSGD_MEM_FAIL);
     DestroyMat(M);
     DestroyArray(pivots);
-    free(cvdls_mem);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_MEM_FAIL);
   }
 
@@ -234,7 +234,7 @@ int CVLapackDense(void *cvode_mem, int N)
  * (*cvode_mem) to the address of this structure.  It sets setupNonNull 
  * in (*cvode_mem) to be TRUE, mu to be mupper, ml to be mlower, and 
  * the jacE and jacI field to NULL.
- * Finally, it allocates memory for M, pivots, and (if needed) savedJ.  
+ * Finally, it allocates memory for M, pivots, and savedJ.  
  * The CVLapackBand return value is CVDLS_SUCCESS = 0, 
  * CVDLS_MEM_FAIL = -1, or CVDLS_ILL_INPUT = -2.
  *
@@ -291,45 +291,46 @@ int CVLapackBand(void *cvode_mem, int N, int mupper, int mlower)
   setupNonNull = TRUE;
   
   /* Load problem dimension */
-  n = N;
+  n = (long int) N;
 
   /* Load half-bandwiths in cvdls_mem */
-  ml = mlower;
-  mu = mupper;
+  ml = (long int) mlower;
+  mu = (long int) mupper;
 
   /* Test ml and mu for legality */
-  if ((ml < 0) || (mu < 0) || (ml >= N) || (mu >= N)) {
+  if ((ml < 0) || (mu < 0) || (ml >= n) || (mu >= n)) {
     CVProcessError(cv_mem, CVDLS_ILL_INPUT, "CVLAPACK", "CVLapackBand", MSGD_BAD_SIZES);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_ILL_INPUT);
   }
 
   /* Set extended upper half-bandwith for M (required for pivoting) */
-  smu = MIN(N-1, mu + ml);
+  smu = MIN(n-1, mu + ml);
 
-  /* Allocate memory for M, savedJ, and pivot arrays */
+  /* Allocate memory for M, pivot array, and savedJ */
   M = NULL;
   pivots = NULL;
   savedJ = NULL;
 
-  M = NewBandMat(N, mu, ml, smu);
+  M = NewBandMat(n, mu, ml, smu);
   if (M == NULL) {
     CVProcessError(cv_mem, CVDLS_MEM_FAIL, "CVLAPACK", "CVLapackBand", MSGD_MEM_FAIL);
-    free(cvdls_mem);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_MEM_FAIL);
   }  
   pivots = NewIntArray(N);
   if (pivots == NULL) {
     CVProcessError(cv_mem, CVDLS_MEM_FAIL, "CVLAPACK", "CVLapackBand", MSGD_MEM_FAIL);
     DestroyMat(M);
-    free(cvdls_mem);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_MEM_FAIL);
   }
-  savedJ = NewBandMat(N, mu, ml, smu);
+  savedJ = NewBandMat(n, mu, ml, smu);
   if (savedJ == NULL) {
     CVProcessError(cv_mem, CVDLS_MEM_FAIL, "CVLAPACK", "CVLapackBand", MSGD_MEM_FAIL);
     DestroyMat(M);
     DestroyArray(pivots);
-    free(cvdls_mem);
+    free(cvdls_mem); cvdls_mem = NULL;
     return(CVDLS_MEM_FAIL);
   }
 
@@ -366,7 +367,7 @@ static int cvLapackDenseInit(CVodeMem cv_mem)
   } else {
     J_data = cv_mem->cv_user_data;
   }
-  
+
   last_flag = CVDLS_SUCCESS;
   return(0);
 }
@@ -387,8 +388,11 @@ static int cvLapackDenseSetup(CVodeMem cv_mem, int convfail,
   realtype dgamma, fact;
   booleantype jbad, jok;
   int ier, retval, one = 1;
+  int intn, lenmat;
 
   cvdls_mem = (CVDlsMem) lmem;
+  intn = (int) n;
+  lenmat = M->ldata ;
 
   /* Use nst, gamma/gammap, and convfail to set J eval. flag jok */
   dgamma = ABS((gamma/gammap) - ONE);
@@ -401,7 +405,7 @@ static int cvLapackDenseSetup(CVodeMem cv_mem, int convfail,
     
     /* If jok = TRUE, use saved copy of J */
     *jcurPtr = FALSE;
-    dcopy_f77(&(savedJ->ldata), savedJ->data, &one, M->data, &one);
+    dcopy_f77(&lenmat, savedJ->data, &one, M->data, &one);
     
   } else {
     
@@ -412,8 +416,9 @@ static int cvLapackDenseSetup(CVodeMem cv_mem, int convfail,
     SetToZero(M);
 
     retval = djac(n, tn, yP, fctP, M, J_data, tmp1, tmp2, tmp3);
+
     if (retval == 0) {
-      dcopy_f77(&(M->ldata), M->data, &one, savedJ->data, &one);
+      dcopy_f77(&lenmat, M->data, &one, savedJ->data, &one);
     } else if (retval < 0) {
       CVProcessError(cv_mem, CVDLS_JACFUNC_UNRECVR, "CVLAPACK", "cvLapackDenseSetup", MSGD_JACFUNC_FAILED);
       last_flag = CVDLS_JACFUNC_UNRECVR;
@@ -427,16 +432,16 @@ static int cvLapackDenseSetup(CVodeMem cv_mem, int convfail,
 
   /* Scale J by - gamma */
   fact = -gamma;
-  dscal_f77(&(M->ldata), &fact, M->data, &one);
+  dscal_f77(&lenmat, &fact, M->data, &one);
   
   /* Add identity to get M = I - gamma*J*/
   AddIdentity(M);
 
   /* Do LU factorization of M */
-  dgetrf_f77(&n, &n, M->data, &(M->ldim), pivots, &ier);
+  dgetrf_f77(&intn, &intn, M->data, &intn, pivots, &ier);
 
   /* Return 0 if the LU was complete; otherwise return 1 */
-  last_flag = ier;
+  last_flag = (long int) ier;
   if (ier > 0) return(1);
   return(0);
 }
@@ -451,18 +456,21 @@ static int cvLapackDenseSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
   CVDlsMem cvdls_mem;
   realtype *bd, fact;
   int ier, one = 1;
+  int intn;
 
   cvdls_mem = (CVDlsMem) lmem;
-  
+  intn = (int) n;
+
   bd = N_VGetArrayPointer(b);
 
-  dgetrs_f77("N", &n, &one, M->data, &(M->ldim), pivots, bd, &n, &ier, 1); 
+  dgetrs_f77("N", &intn, &one, M->data, &intn, pivots, bd, &intn, &ier, 1); 
+
   if (ier > 0) return(1);
 
   /* For BDF, scale the correction to account for change in gamma */
   if ((lmm == CV_BDF) && (gamrat != ONE)) {
     fact = TWO/(ONE + gamrat);
-    dscal_f77(&n, &fact, bd, &one); 
+    dscal_f77(&intn, &fact, bd, &one); 
   }
   
   last_flag = CVDLS_SUCCESS;
@@ -533,8 +541,14 @@ static int cvLapackBandSetup(CVodeMem cv_mem, int convfail,
   realtype dgamma, fact;
   booleantype jbad, jok;
   int ier, retval, one = 1;
+  int intn, iml, imu, lenmat, ldmat;
 
   cvdls_mem = (CVDlsMem) lmem;
+  intn = (int) n;
+  iml = (int) ml;
+  imu = (int) mu;
+  lenmat = M->ldata;
+  ldmat = M->ldim;
 
   /* Use nst, gamma/gammap, and convfail to set J eval. flag jok */
   dgamma = ABS((gamma/gammap) - ONE);
@@ -547,7 +561,7 @@ static int cvLapackBandSetup(CVodeMem cv_mem, int convfail,
     
     /* If jok = TRUE, use saved copy of J */
     *jcurPtr = FALSE;
-    dcopy_f77(&(savedJ->ldata), savedJ->data, &one, M->data, &one);
+    dcopy_f77(&lenmat, savedJ->data, &one, M->data, &one);
     
   } else {
     
@@ -559,7 +573,7 @@ static int cvLapackBandSetup(CVodeMem cv_mem, int convfail,
 
     retval = bjac(n, mu, ml, tn, yP, fctP, M, J_data, tmp1, tmp2, tmp3);
     if (retval == 0) {
-      dcopy_f77(&(M->ldata), M->data, &one, savedJ->data, &one);
+      dcopy_f77(&lenmat, M->data, &one, savedJ->data, &one);
     } else if (retval < 0) {
       CVProcessError(cv_mem, CVDLS_JACFUNC_UNRECVR, "CVLAPACK", "cvLapackBandSetup", MSGD_JACFUNC_FAILED);
       last_flag = CVDLS_JACFUNC_UNRECVR;
@@ -573,16 +587,16 @@ static int cvLapackBandSetup(CVodeMem cv_mem, int convfail,
   
   /* Scale J by - gamma */
   fact = -gamma;
-  dscal_f77(&(M->ldata), &fact, M->data, &one);
+  dscal_f77(&lenmat, &fact, M->data, &one);
   
   /* Add identity to get M = I - gamma*J*/
   AddIdentity(M);
   
   /* Do LU factorization of M */
-  dgbtrf_f77(&n, &n, &ml, &mu, M->data, &(M->ldim), pivots, &ier);
+  dgbtrf_f77(&intn, &intn, &iml, &imu, M->data, &ldmat, pivots, &ier);
 
   /* Return 0 if the LU was complete; otherwise return 1 */
-  last_flag = ier;
+  last_flag = (long int) ier;
   if (ier > 0) return(1);
   return(0);
 
@@ -598,18 +612,23 @@ static int cvLapackBandSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
   CVDlsMem cvdls_mem;
   realtype *bd, fact;
   int ier, one = 1;
+  int intn, iml, imu, ldmat;
 
   cvdls_mem = (CVDlsMem) lmem;
+  intn = (int) n;
+  iml = (int) ml;
+  imu = (int) mu;
+  ldmat = M->ldim;
 
   bd = N_VGetArrayPointer(b);
 
-  dgbtrs_f77("N", &n, &ml, &mu, &one, M->data, &(M->ldim), pivots, bd, &n, &ier, 1);
+  dgbtrs_f77("N", &intn, &iml, &imu, &one, M->data, &ldmat, pivots, bd, &intn, &ier, 1);
   if (ier > 0) return(1);
 
   /* For BDF, scale the correction to account for change in gamma */
   if ((lmm == CV_BDF) && (gamrat != ONE)) {
     fact = TWO/(ONE + gamrat);
-    dscal_f77(&n, &fact, bd, &one); 
+    dscal_f77(&intn, &fact, bd, &one); 
   }
 
   last_flag = CVDLS_SUCCESS;
