@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.8 $
- * $Date: 2008/09/10 22:39:03 $
+ * $Revision: 1.10 $
+ * $Date: 2011/03/23 22:27:43 $
  * ----------------------------------------------------------------- 
  * Programmer(s): Scott D. Cohen, Alan C. Hindmarsh and
  *                Radu Serban @ LLNL
@@ -170,6 +170,7 @@ int CVSpgmr(void *cvode_mem, int pretype, int maxl)
   if ((pretype != PREC_NONE) && (pretype != PREC_LEFT) &&
       (pretype != PREC_RIGHT) && (pretype != PREC_BOTH)) {
     CVProcessError(cv_mem, CVSPILS_ILL_INPUT, "CVSPGMR", "CVSpgmr", MSGS_BAD_PRETYPE);
+    free(cvspils_mem); cvspils_mem = NULL;
     return(CVSPILS_ILL_INPUT);
   }
 
@@ -456,6 +457,7 @@ static void CVSpgmrFree(CVodeMem cv_mem)
 
   if (cvspils_mem->s_pfree != NULL) (cvspils_mem->s_pfree)(cv_mem);
 
-  free(cvspils_mem); cvspils_mem = NULL;
+  free(cvspils_mem);
+  cv_mem->cv_lmem = NULL;
 }
 
