@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2006/10/11 16:34:15 $
+ * $Revision: 1.14 $
+ * $Date: 2010/12/01 22:30:43 $
  * ----------------------------------------------------------------- 
  * Programmer(s): Radu Serban and Aaron Collier @ LLNL
  * -----------------------------------------------------------------
@@ -22,6 +22,7 @@
 
 #include "cvodes_impl.h"
 #include "cvodes_bbdpre_impl.h"
+#include "cvodes_spils_impl.h"
 
 #include <cvodes/cvodes_sptfqmr.h>
 #include <cvodes/cvodes_spbcgs.h>
@@ -30,35 +31,35 @@
 #include <sundials/sundials_math.h>
 
 #define MIN_INC_MULT RCONST(1000.0)
+
 #define ZERO         RCONST(0.0)
 #define ONE          RCONST(1.0)
 
-/* Prototypes of functions CVBBDPrecSetup and CVBBDPrecSolve */
-
-static int CVBBDPrecSetup(realtype t, N_Vector y, N_Vector fy, 
+/* Prototypes of functions cvBBDPrecSetup and cvBBDPrecSolve */
+static int cvBBDPrecSetup(realtype t, N_Vector y, N_Vector fy, 
                           booleantype jok, booleantype *jcurPtr, 
                           realtype gamma, void *bbd_data, 
                           N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
-
-static int CVBBDPrecSolve(realtype t, N_Vector y, N_Vector fy, 
+static int cvBBDPrecSolve(realtype t, N_Vector y, N_Vector fy, 
                           N_Vector r, N_Vector z, 
                           realtype gamma, realtype delta,
                           int lr, void *bbd_data, N_Vector tmp);
 
+/* Prototype for cvBBDPrecFree */
+static void cvBBDPrecFree(CVodeMem cv_mem);
+
 /* Wrapper functions for adjoint code */
-
-static int CVAgloc(long int NlocalB, realtype t, N_Vector yB, N_Vector gB, 
-                   void *cvadj_mem);
-
-static int CVAcfn(long int NlocalB, realtype t, N_Vector yB,
-                  void *cvadj_mem);
+static int cvGlocWrapper(long int NlocalB, realtype t, N_Vector yB, N_Vector gB, 
+                         void *cvadj_mem);
+static int cvCfnWrapper(long int NlocalB, realtype t, N_Vector yB, void *cvadj_mem);
 
 /* Prototype for difference quotient Jacobian calculation routine */
-
-static int CVBBDDQJac(CVBBDPrecData pdata, realtype t, 
+static int cvBBDDQJac(CVBBDPrecData pdata, realtype t, 
                       N_Vector y, N_Vector gy, 
                       N_Vector ytemp, N_Vector gtemp);
 
+/* Prototype for the pfree routine */
+static void CVBBDPrecFreeB(CVodeBMem cvB_mem);
 
 /* 
  * ================================================================
@@ -75,38 +76,47 @@ static int CVBBDDQJac(CVBBDPrecData pdata, realtype t,
 
 /*
  * -----------------------------------------------------------------
- * User-Callable Functions: malloc, reinit and free
+ * User-Callable Functions: initialization, reinit and free
  * -----------------------------------------------------------------
  */
 
-void *CVBBDPrecAlloc(void *cvode_mem, long int Nlocal, 
-                     long int mudq, long int mldq,
-                     long int mukeep, long int mlkeep, 
-                     realtype dqrely, 
-                     CVLocalFn gloc, CVCommFn cfn)
+int CVBBDPrecInit(void *cvode_mem, long int Nlocal, 
+                  long int mudq, long int mldq,
+                  long int mukeep, long int mlkeep, 
+                  realtype dqrely, 
+                  CVLocalFn gloc, CVCommFn cfn)
 {
   CVodeMem cv_mem;
+  CVSpilsMem cvspils_mem;
   CVBBDPrecData pdata;
   long int muk, mlk, storage_mu;
+  int flag;
 
   if (cvode_mem == NULL) {
-    CVProcessError(NULL, 0, "CVBBDPRE", "CVBBDPrecAlloc", MSGBBDP_CVMEM_NULL);
-    return(NULL);
+    cvProcessError(NULL, CVSPILS_MEM_NULL, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_MEM_NULL);
+    return(CVSPILS_MEM_NULL);
   }
   cv_mem = (CVodeMem) cvode_mem;
 
+  /* Test if one of the SPILS linear solvers has been attached */
+  if (cv_mem->cv_lmem == NULL) {
+    cvProcessError(cv_mem, CVSPILS_LMEM_NULL, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_LMEM_NULL);
+    return(CVSPILS_LMEM_NULL);
+  }
+  cvspils_mem = (CVSpilsMem) cv_mem->cv_lmem;
+
   /* Test if the NVECTOR package is compatible with the BLOCK BAND preconditioner */
   if(vec_tmpl->ops->nvgetarraypointer == NULL) {
-    CVProcessError(cv_mem, 0, "CVBBDPRE", "CVBBDPrecAlloc", MSGBBDP_BAD_NVECTOR);
-    return(NULL);
+    cvProcessError(cv_mem, CVSPILS_ILL_INPUT, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_BAD_NVECTOR);
+    return(CVSPILS_ILL_INPUT);
   }
 
   /* Allocate data memory */
   pdata = NULL;
   pdata = (CVBBDPrecData) malloc(sizeof *pdata);  
   if (pdata == NULL) {
-    CVProcessError(cv_mem, 0, "CVBBDPRE", "CVBBDPrecAlloc", MSGBBDP_MEM_FAIL);
-    return(NULL);
+    cvProcessError(cv_mem, CVSPILS_MEM_FAIL, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_MEM_FAIL);
+    return(CVSPILS_MEM_FAIL);
   }
 
   /* Set pointers to gloc and cfn; load half-bandwidths */
@@ -121,32 +131,32 @@ void *CVBBDPrecAlloc(void *cvode_mem, long int Nlocal,
   pdata->mlkeep = mlk;
 
   /* Allocate memory for saved Jacobian */
-  pdata->savedJ = BandAllocMat(Nlocal, muk, mlk, muk);
+  pdata->savedJ = NewBandMat(Nlocal, muk, mlk, muk);
   if (pdata->savedJ == NULL) { 
     free(pdata); pdata = NULL; 
-    CVProcessError(cv_mem, 0, "CVBBDPRE", "CVBBDPrecAlloc", MSGBBDP_MEM_FAIL);
-    return(NULL); 
+    cvProcessError(cv_mem, CVSPILS_MEM_FAIL, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_MEM_FAIL);
+    return(CVSPILS_MEM_FAIL); 
   }
 
   /* Allocate memory for preconditioner matrix */
   storage_mu = MIN(Nlocal-1, muk + mlk);
   pdata->savedP = NULL;
-  pdata->savedP = BandAllocMat(Nlocal, muk, mlk, storage_mu);
+  pdata->savedP = NewBandMat(Nlocal, muk, mlk, storage_mu);
   if (pdata->savedP == NULL) {
-    BandFreeMat(pdata->savedJ);
+    DestroyMat(pdata->savedJ);
     free(pdata); pdata = NULL;
-    CVProcessError(cv_mem, 0, "CVBBDPRE", "CVBBDPrecAlloc", MSGBBDP_MEM_FAIL);
-    return(NULL);
+    cvProcessError(cv_mem, CVSPILS_MEM_FAIL, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_MEM_FAIL);
+    return(CVSPILS_MEM_FAIL);
   }
-  /* Allocate memory for pivots */
-  pdata->pivots = NULL;
-  pdata->pivots = BandAllocPiv(Nlocal);
-  if (pdata->savedJ == NULL) {
-    BandFreeMat(pdata->savedP);
-    BandFreeMat(pdata->savedJ);
+  /* Allocate memory for lpivots */
+  pdata->lpivots = NULL;
+  pdata->lpivots = NewLintArray(Nlocal);
+  if (pdata->lpivots == NULL) {
+    DestroyMat(pdata->savedP);
+    DestroyMat(pdata->savedJ);
     free(pdata); pdata = NULL;
-    CVProcessError(cv_mem, 0, "CVBBDPRE", "CVBBDPrecAlloc", MSGBBDP_MEM_FAIL);
-    return(NULL);
+    cvProcessError(cv_mem, CVSPILS_MEM_FAIL, "CVBBDPRE", "CVBBDPrecInit", MSGBBD_MEM_FAIL);
+    return(CVSPILS_MEM_FAIL);
   }
 
   /* Set pdata->dqrely based on input dqrely (0 implies default). */
@@ -160,92 +170,49 @@ void *CVBBDPrecAlloc(void *cvode_mem, long int Nlocal,
   pdata->ipwsize = Nlocal;
   pdata->nge = 0;
 
-  return((void *)pdata);
+  /* Overwrite the P_data field in the SPILS memory */
+  cvspils_mem->s_P_data = pdata;
+
+  /* Attach the pfree function */
+  cvspils_mem->s_pfree = cvBBDPrecFree;
+
+  /* Attach preconditioner solve and setup functions */
+  flag = CVSpilsSetPreconditioner(cvode_mem, cvBBDPrecSetup, cvBBDPrecSolve);
+
+  return(flag);
 }
 
-int CVBBDSptfqmr(void *cvode_mem, int pretype, int maxl, void *bbd_data)
-{
-  CVodeMem cv_mem;
-  int flag;
 
-  flag = CVSptfqmr(cvode_mem, pretype, maxl);
-  if(flag != CVSPILS_SUCCESS) return(flag);
-
-  cv_mem = (CVodeMem) cvode_mem;
-
-  if (bbd_data == NULL) {
-    CVProcessError(cv_mem, CVBBDPRE_PDATA_NULL, "CVBBDPRE", "CVBBDSptfqmr", MSGBBDP_PDATA_NULL);
-    return(CVBBDPRE_PDATA_NULL);
-  } 
-
-  flag = CVSpilsSetPreconditioner(cvode_mem, CVBBDPrecSetup, CVBBDPrecSolve, bbd_data);
-  if(flag != CVSPILS_SUCCESS) return(flag);
-
-  return(CVSPILS_SUCCESS);
-}
-
-int CVBBDSpbcg(void *cvode_mem, int pretype, int maxl, void *bbd_data)
-{
-  CVodeMem cv_mem;
-  int flag;
-
-  flag = CVSpbcg(cvode_mem, pretype, maxl);
-  if(flag != CVSPILS_SUCCESS) return(flag);
-
-  cv_mem = (CVodeMem) cvode_mem;
-
-  if (bbd_data == NULL) {
-    CVProcessError(cv_mem, CVBBDPRE_PDATA_NULL, "CVBBDPRE", "CVBBDSpbcg", MSGBBDP_PDATA_NULL);
-    return(CVBBDPRE_PDATA_NULL);
-  } 
-
-  flag = CVSpilsSetPreconditioner(cvode_mem, CVBBDPrecSetup, CVBBDPrecSolve, bbd_data);
-  if(flag != CVSPILS_SUCCESS) return(flag);
-
-  return(CVSPILS_SUCCESS);
-}
-
-int CVBBDSpgmr(void *cvode_mem, int pretype, int maxl, void *bbd_data)
-{
-  CVodeMem cv_mem;
-  int flag;
-
-  flag = CVSpgmr(cvode_mem, pretype, maxl);
-  if(flag != CVSPILS_SUCCESS) return(flag);
-
-  cv_mem = (CVodeMem) cvode_mem;
-
-  if (bbd_data == NULL) {
-    CVProcessError(cv_mem, CVBBDPRE_PDATA_NULL, "CVBBDPRE", "CVBBDSpgmr", MSGBBDP_PDATA_NULL);
-    return(CVBBDPRE_PDATA_NULL);
-  } 
-
-  flag = CVSpilsSetPreconditioner(cvode_mem, CVBBDPrecSetup, CVBBDPrecSolve, bbd_data);
-  if(flag != CVSPILS_SUCCESS) return(flag);
-
-  return(CVSPILS_SUCCESS);
-}
-
-int CVBBDPrecReInit(void *bbd_data, 
+int CVBBDPrecReInit(void *cvode_mem, 
                     long int mudq, long int mldq, 
-                    realtype dqrely, 
-                    CVLocalFn gloc, CVCommFn cfn)
+                    realtype dqrely)
 {
-  CVBBDPrecData pdata;
   CVodeMem cv_mem;
+  CVSpilsMem cvspils_mem;
+  CVBBDPrecData pdata;
   long int Nlocal;
 
-  if (bbd_data == NULL) {
-    CVProcessError(NULL, CVBBDPRE_PDATA_NULL, "CVBBDPRE", "CVBBDPrecReInit", MSGBBDP_PDATA_NULL);
-    return(CVBBDPRE_PDATA_NULL);
+  if (cvode_mem == NULL) {
+    cvProcessError(NULL, CVSPILS_MEM_NULL, "CVBBDPRE", "CVBBDPrecReInit", MSGBBD_MEM_NULL);
+    return(CVSPILS_MEM_NULL);
+  }
+  cv_mem = (CVodeMem) cvode_mem;
+
+  /* Test if one of the SPILS linear solvers has been attached */
+  if (cv_mem->cv_lmem == NULL) {
+    cvProcessError(cv_mem, CVSPILS_LMEM_NULL, "CVBBDPRE", "CVBBDPrecReInit", MSGBBD_LMEM_NULL);
+    return(CVSPILS_LMEM_NULL);
+  }
+  cvspils_mem = (CVSpilsMem) cv_mem->cv_lmem;
+
+  /* Test if the preconditioner data is non-NULL */
+  if (cvspils_mem->s_P_data == NULL) {
+    cvProcessError(cv_mem, CVSPILS_PMEM_NULL, "CVBBDPRE", "CVBBDPrecReInit", MSGBBD_PMEM_NULL);
+    return(CVSPILS_PMEM_NULL);
   } 
+  pdata = (CVBBDPrecData) cvspils_mem->s_P_data;
 
-  pdata  = (CVBBDPrecData) bbd_data;
-  cv_mem = (CVodeMem) pdata->cvode_mem;
-
-  /* Set pointers to gloc and cfn; load half-bandwidths */
-  pdata->gloc = gloc;
-  pdata->cfn = cfn;
+  /* Load half-bandwidths */
   Nlocal = pdata->n_local;
   pdata->mudq = MIN(Nlocal-1, MAX(0,mudq));
   pdata->mldq = MIN(Nlocal-1, MAX(0,mldq));
@@ -256,124 +223,96 @@ int CVBBDPrecReInit(void *bbd_data,
   /* Re-initialize nge */
   pdata->nge = 0;
 
-  return(CVBBDPRE_SUCCESS);
+  return(CVSPILS_SUCCESS);
 }
 
-void CVBBDPrecFree(void **bbd_data)
-{
-  CVBBDPrecData pdata;
-  
-  if (*bbd_data == NULL) return;
-
-  pdata = (CVBBDPrecData) (*bbd_data);
-  BandFreeMat(pdata->savedJ);
-  BandFreeMat(pdata->savedP);
-  BandFreePiv(pdata->pivots);
-
-  free(*bbd_data);
-  *bbd_data = NULL;
-
-}
-
-int CVBBDPrecGetWorkSpace(void *bbd_data, long int *lenrwBBDP, long int *leniwBBDP)
+int CVBBDPrecGetWorkSpace(void *cvode_mem, long int *lenrwBBDP, long int *leniwBBDP)
 {
+  CVodeMem cv_mem;
+  CVSpilsMem cvspils_mem;
   CVBBDPrecData pdata;
 
-  if (bbd_data == NULL) {
-    CVProcessError(NULL, CVBBDPRE_PDATA_NULL, "CVBBDPRE", "CVBBDPrecGetWorkSpace", MSGBBDP_PDATA_NULL);    
-    return(CVBBDPRE_PDATA_NULL);
+  if (cvode_mem == NULL) {
+    cvProcessError(NULL, CVSPILS_MEM_NULL, "CVBBDPRE", "CVBBDPrecGetWorkSpace", MSGBBD_MEM_NULL);
+    return(CVSPILS_MEM_NULL);
+  }
+  cv_mem = (CVodeMem) cvode_mem;
+
+  if (cv_mem->cv_lmem == NULL) {
+    cvProcessError(cv_mem, CVSPILS_LMEM_NULL, "CVBBDPRE", "CVBBDPrecGetWorkSpace", MSGBBD_LMEM_NULL);
+    return(CVSPILS_LMEM_NULL);
+  }
+  cvspils_mem = (CVSpilsMem) cv_mem->cv_lmem;
+
+  if (cvspils_mem->s_P_data == NULL) {
+    cvProcessError(cv_mem, CVSPILS_PMEM_NULL, "CVBBDPRE", "CVBBDPrecGetWorkSpace", MSGBBD_PMEM_NULL);
+    return(CVSPILS_PMEM_NULL);
   } 
-
-  pdata = (CVBBDPrecData) bbd_data;
+  pdata = (CVBBDPrecData) cvspils_mem->s_P_data;
 
   *lenrwBBDP = pdata->rpwsize;
   *leniwBBDP = pdata->ipwsize;
 
-  return(CVBBDPRE_SUCCESS);
+  return(CVSPILS_SUCCESS);
 }
 
-int CVBBDPrecGetNumGfnEvals(void *bbd_data, long int *ngevalsBBDP)
+int CVBBDPrecGetNumGfnEvals(void *cvode_mem, long int *ngevalsBBDP)
 {
+  CVodeMem cv_mem;
+  CVSpilsMem cvspils_mem;
   CVBBDPrecData pdata;
 
-  if (bbd_data == NULL) {
-    CVProcessError(NULL, CVBBDPRE_PDATA_NULL, "CVBBDPRE", "CVBBDPrecGetNumGfnEvals", MSGBBDP_PDATA_NULL);
-    return(CVBBDPRE_PDATA_NULL);
-  } 
+  if (cvode_mem == NULL) {
+    cvProcessError(NULL, CVSPILS_MEM_NULL, "CVBBDPRE", "CVBBDPrecGetNumGfnEvals", MSGBBD_MEM_NULL);
+    return(CVSPILS_MEM_NULL);
+  }
+  cv_mem = (CVodeMem) cvode_mem;
 
-  pdata = (CVBBDPrecData) bbd_data;
+  if (cv_mem->cv_lmem == NULL) {
+    cvProcessError(cv_mem, CVSPILS_LMEM_NULL, "CVBBDPRE", "CVBBDPrecGetNumGfnEvals", MSGBBD_LMEM_NULL);
+    return(CVSPILS_LMEM_NULL);
+  }
+  cvspils_mem = (CVSpilsMem) cv_mem->cv_lmem;
+
+  if (cvspils_mem->s_P_data == NULL) {
+    cvProcessError(cv_mem, CVSPILS_PMEM_NULL, "CVBBDPRE", "CVBBDPrecGetNumGfnEvals", MSGBBD_PMEM_NULL);
+    return(CVSPILS_PMEM_NULL);
+  } 
+  pdata = (CVBBDPrecData) cvspils_mem->s_P_data;
 
   *ngevalsBBDP = pdata->nge;
 
-  return(CVBBDPRE_SUCCESS);
-}
-
-/*
- * -----------------------------------------------------------------
- * CVBBDPrecGetReturnFlagName
- * -----------------------------------------------------------------
- */
-
-char *CVBBDPrecGetReturnFlagName(int flag)
-{
-  char *name;
-
-  name = (char *)malloc(30*sizeof(char));
-
-  switch(flag) {
-  case CVBBDPRE_SUCCESS:
-    sprintf(name,"CVBBDPRE_SUCCESS");
-    break; 
-  case CVBBDPRE_PDATA_NULL:
-    sprintf(name,"CVBBDPRE_PDATA_NULL");
-    break;
-  case CVBBDPRE_FUNC_UNRECVR:
-    sprintf(name,"CVBBDPRE_FUNC_UNRECVR");
-    break;
-  case CVBBDPRE_ADJMEM_NULL:
-    sprintf(name,"CVBBDPRE_ADJMEM_NULL");
-    break;
-  case CVBBDPRE_PDATAB_NULL:
-    sprintf(name,"CVBBDPRE_PDATAB_NULL");
-    break;
-  case CVBBDPRE_MEM_FAIL:
-    sprintf(name,"CVBBDPRE_MEM_FAIL");
-    break;
-  default:
-    sprintf(name,"NONE");
-  }
-
-  return(name);
+  return(CVSPILS_SUCCESS);
 }
 
 /* Readability Replacements */
 
-#define Nlocal (pdata->n_local)
-#define mudq   (pdata->mudq)
-#define mldq   (pdata->mldq)
-#define mukeep (pdata->mukeep)
-#define mlkeep (pdata->mlkeep)
-#define dqrely (pdata->dqrely)
-#define gloc   (pdata->gloc)
-#define cfn    (pdata->cfn)
-#define savedJ (pdata->savedJ)
-#define savedP (pdata->savedP)
-#define pivots (pdata->pivots)
-#define nge    (pdata->nge)
+#define Nlocal  (pdata->n_local)
+#define mudq    (pdata->mudq)
+#define mldq    (pdata->mldq)
+#define mukeep  (pdata->mukeep)
+#define mlkeep  (pdata->mlkeep)
+#define dqrely  (pdata->dqrely)
+#define gloc    (pdata->gloc)
+#define cfn     (pdata->cfn)
+#define savedJ  (pdata->savedJ)
+#define savedP  (pdata->savedP)
+#define lpivots (pdata->lpivots)
+#define nge     (pdata->nge)
 
 /*
  * -----------------------------------------------------------------
- * Function : CVBBDPrecSetup                                      
+ * Function : cvBBDPrecSetup                                      
  * -----------------------------------------------------------------
- * CVBBDPrecSetup generates and factors a banded block of the
+ * cvBBDPrecSetup generates and factors a banded block of the
  * preconditioner matrix on each processor, via calls to the
  * user-supplied gloc and cfn functions. It uses difference
  * quotient approximations to the Jacobian elements.
  *
- * CVBBDPrecSetup calculates a new J,if necessary, then calculates
+ * cvBBDPrecSetup calculates a new J,if necessary, then calculates
  * P = I - gamma*J, and does an LU factorization of P.
  *
- * The parameters of CVBBDPrecSetup used here are as follows:
+ * The parameters of cvBBDPrecSetup used here are as follows:
  *
  * t       is the current value of the independent variable.
  *
@@ -400,30 +339,29 @@ char *CVBBDPrecGetReturnFlagName(int flag)
  *
  * gamma   is the scalar appearing in the Newton matrix.
  *
- * bbd_data  is a pointer to user data - the same as the P_data
- *           parameter passed to CVSp*. For CVBBDPrecon,
- *           this should be of type CVBBDData.
+ * bbd_data is a pointer to the preconditioner data set by
+ *          CVBBDPrecInit
  *
  * tmp1, tmp2, and tmp3 are pointers to memory allocated
- *           for NVectors which are be used by CVBBDPrecSetup
+ *           for NVectors which are be used by cvBBDPrecSetup
  *           as temporary storage or work space.
  *
  * Return value:
- * The value returned by this CVBBDPrecSetup function is the int
+ * The value returned by this cvBBDPrecSetup function is the int
  *   0  if successful,
  *   1  for a recoverable error (step will be retried).
  * -----------------------------------------------------------------
  */
 
-static int CVBBDPrecSetup(realtype t, N_Vector y, N_Vector fy, 
+static int cvBBDPrecSetup(realtype t, N_Vector y, N_Vector fy, 
                           booleantype jok, booleantype *jcurPtr, 
                           realtype gamma, void *bbd_data, 
                           N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
 {
-  long int ier;
   CVBBDPrecData pdata;
   CVodeMem cv_mem;
   int retval;
+  long int ier;
 
   pdata = (CVBBDPrecData) bbd_data;
 
@@ -437,13 +375,13 @@ static int CVBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
 
   } else {
 
-    /* Otherwise call CVBBDDQJac for new J value */
+    /* Otherwise call cvBBDDQJac for new J value */
     *jcurPtr = TRUE;
-    BandZero(savedJ);
+    SetToZero(savedJ);
 
-    retval = CVBBDDQJac(pdata, t, y, tmp1, tmp2, tmp3);
+    retval = cvBBDDQJac(pdata, t, y, tmp1, tmp2, tmp3);
     if (retval < 0) {
-      CVProcessError(cv_mem, CVBBDPRE_FUNC_UNRECVR, "CVBBDPRE", "CVBBDPrecSetup", MSGBBDP_FUNC_FAILED);
+      cvProcessError(cv_mem, -1, "CVBBDPRE", "cvBBDPrecSetup", MSGBBD_FUNC_FAILED);
       return(-1);
     }
     if (retval > 0) {
@@ -456,10 +394,10 @@ static int CVBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
   
   /* Scale and add I to get P = I - gamma*J */
   BandScale(-gamma, savedP);
-  BandAddI(savedP);
+  AddIdentity(savedP);
  
   /* Do LU factorization of P in place */
-  ier = BandGBTRF(savedP, pivots);
+  ier = BandGBTRF(savedP, lpivots);
  
   /* Return 0 if the LU was complete; otherwise return 1 */
   if (ier > 0) return(1);
@@ -468,27 +406,27 @@ static int CVBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
 
 /*
  * -----------------------------------------------------------------
- * Function : CVBBDPrecSolve
+ * Function : cvBBDPrecSolve
  * -----------------------------------------------------------------
- * CVBBDPrecSolve solves a linear system P z = r, with the
+ * cvBBDPrecSolve solves a linear system P z = r, with the
  * band-block-diagonal preconditioner matrix P generated and
- * factored by CVBBDPrecSetup.
+ * factored by cvBBDPrecSetup.
  *
- * The parameters of CVBBDPrecSolve used here are as follows:
+ * The parameters of cvBBDPrecSolve used here are as follows:
  *
- * r      is the right-hand side vector of the linear system.
+ * r is the right-hand side vector of the linear system.
  *
- * bbd_data is a pointer to the preconditioner data returned by
- *          CVBBDPrecAlloc.
+ * bbd_data is a pointer to the preconditioner data set by
+ *   CVBBDPrecInit.
  *
- * z      is the output vector computed by CVBBDPrecSolve.
+ * z is the output vector computed by cvBBDPrecSolve.
  *
- * The value returned by the CVBBDPrecSolve function is always 0,
+ * The value returned by the cvBBDPrecSolve function is always 0,
  * indicating success.
  * -----------------------------------------------------------------
  */
 
-static int CVBBDPrecSolve(realtype t, N_Vector y, N_Vector fy, 
+static int cvBBDPrecSolve(realtype t, N_Vector y, N_Vector fy, 
                           N_Vector r, N_Vector z, 
                           realtype gamma, realtype delta,
                           int lr, void *bbd_data, N_Vector tmp)
@@ -503,18 +441,40 @@ static int CVBBDPrecSolve(realtype t, N_Vector y, N_Vector fy,
   
   zd = N_VGetArrayPointer(z);
 
-  BandGBTRS(savedP, pivots, zd);
+  BandGBTRS(savedP, lpivots, zd);
 
   return(0);
 }
 
-#define ewt    (cv_mem->cv_ewt)
-#define h      (cv_mem->cv_h)
-#define f_data (cv_mem->cv_f_data)
+
+static void cvBBDPrecFree(CVodeMem cv_mem)
+{
+  CVSpilsMem cvspils_mem;
+  CVBBDPrecData pdata;
+  
+  if (cv_mem->cv_lmem == NULL) return;
+  cvspils_mem = (CVSpilsMem) cv_mem->cv_lmem;
+  
+  if (cvspils_mem->s_P_data == NULL) return;
+  pdata = (CVBBDPrecData) cvspils_mem->s_P_data;
+
+  DestroyMat(savedJ);
+  DestroyMat(savedP);
+  DestroyArray(lpivots);
+
+  free(pdata);
+  pdata = NULL;
+}
+
+
+
+#define ewt       (cv_mem->cv_ewt)
+#define h         (cv_mem->cv_h)
+#define user_data (cv_mem->cv_user_data)
 
 /*
  * -----------------------------------------------------------------
- * Function : CVBBDDQJac
+ * Function : cvBBDDQJac
  * -----------------------------------------------------------------
  * This routine generates a banded difference quotient approximation
  * to the local block of the Jacobian of g(t,y). It assumes that a
@@ -529,7 +489,7 @@ static int CVBBDPrecSolve(realtype t, N_Vector y, N_Vector fy,
  * -----------------------------------------------------------------
  */
 
-static int CVBBDDQJac(CVBBDPrecData pdata, realtype t, 
+static int cvBBDDQJac(CVBBDPrecData pdata, realtype t, 
                       N_Vector y, N_Vector gy, 
                       N_Vector ytemp, N_Vector gtemp)
 {
@@ -546,11 +506,11 @@ static int CVBBDDQJac(CVBBDPrecData pdata, realtype t,
 
   /* Call cfn and gloc to get base value of g(t,y) */
   if (cfn != NULL) {
-    retval = cfn(Nlocal, t, y, f_data);
+    retval = cfn(Nlocal, t, y, user_data);
     if (retval != 0) return(retval);
   }
 
-  retval = gloc(Nlocal, t, ytemp, gy, f_data);
+  retval = gloc(Nlocal, t, ytemp, gy, user_data);
   nge++;
   if (retval != 0) return(retval);
 
@@ -580,7 +540,7 @@ static int CVBBDDQJac(CVBBDPrecData pdata, realtype t,
     }
 
     /* Evaluate g with incremented y */
-    retval = gloc(Nlocal, t, ytemp, gtemp, f_data);
+    retval = gloc(Nlocal, t, ytemp, gtemp, user_data);
     nge++;
     if (retval != 0) return(retval);
 
@@ -613,270 +573,212 @@ static int CVBBDDQJac(CVBBDPrecData pdata, realtype t,
 
 /* Additional readability replacements */
 
-#define ytmp        (ca_mem->ca_ytmp)
-#define f_data_B    (ca_mem->ca_f_dataB)
-#define getY        (ca_mem->ca_getY)
-#define pmemB       (ca_mem->ca_pmemB)
-
-#define bbd_data_B  (cvbbdB_mem->bbd_dataB)
-#define gloc_B      (cvbbdB_mem->glocB)
-#define cfn_B       (cvbbdB_mem->cfnB)
+#define ytmp  (ca_mem->ca_ytmp)
+#define yStmp (ca_mem->ca_yStmp)
+#define IMget (ca_mem->ca_IMget)
 
+#define gloc_B     (cvbbdB_mem->glocB)
+#define cfn_B      (cvbbdB_mem->cfnB)
 
 /*
- * CVBBDPrecAllocB, CVBPSp*B
+ * CVBBDPrecInitB, CVBPSp*B
  *
- * Wrappers for the backward phase around the corresponding 
- * CVODES functions
+ * Wrappers for the backward phase around the corresponding CVODES functions
  */
 
-int CVBBDPrecAllocB(void *cvadj_mem, long int NlocalB, 
-                    long int mudqB, long int mldqB, 
-                    long int mukeepB, long int mlkeepB, 
-                    realtype dqrelyB,
-                    CVLocalFnB glocB, CVCommFnB cfnB)
+int CVBBDPrecInitB(void *cvode_mem, int which, long int NlocalB, 
+                   long int mudqB, long int mldqB,
+                   long int mukeepB, long int mlkeepB, 
+                   realtype dqrelyB,
+                   CVLocalFnB glocB, CVCommFnB cfnB)
 {
+  CVodeMem cv_mem;
   CVadjMem ca_mem;
+  CVodeBMem cvB_mem;
+  void *cvodeB_mem;
   CVBBDPrecDataB cvbbdB_mem;
-  CVodeMem cvB_mem;
-  void *bbd_dataB;
+  int flag;
 
-  if (cvadj_mem == NULL) {
-    CVProcessError(NULL, CVBBDPRE_ADJMEM_NULL, "CVBBDPRE", "CVBBDPrecAllocB", MSGBBDP_CAMEM_NULL);
-    return(CVBBDPRE_ADJMEM_NULL);
+  /* Check if cvode_mem exists */
+  if (cvode_mem == NULL) {
+    cvProcessError(NULL, CVSPILS_MEM_NULL, "CVBBDPRE", "CVBBDPrecInitB", MSGBBD_MEM_NULL);
+    return(CVSPILS_MEM_NULL);
   }
-  ca_mem = (CVadjMem) cvadj_mem;
+  cv_mem = (CVodeMem) cvode_mem;
 
-  cvB_mem = ca_mem->cvb_mem;
+  /* Was ASA initialized? */
+  if (cv_mem->cv_adjMallocDone == FALSE) {
+    cvProcessError(cv_mem, CVSPILS_NO_ADJ, "CVBBDPRE", "CVBBDPrecInitB", MSGBBD_NO_ADJ);
+    return(CVSPILS_NO_ADJ);
+  } 
+  ca_mem = cv_mem->cv_adj_mem;
 
-  /* Get memory for CVBBDPrecDataB */
+  /* Check which */
+  if ( which >= ca_mem->ca_nbckpbs ) {
+    cvProcessError(cv_mem, CVSPILS_ILL_INPUT, "CVBBDPRE", "CVBBDPrecInitB", MSGBBD_BAD_WHICH);
+    return(CVSPILS_ILL_INPUT);
+  }
+
+  /* Find the CVodeBMem entry in the linked list corresponding to which */
+  cvB_mem = ca_mem->cvB_mem;
+  while (cvB_mem != NULL) {
+    if ( which == cvB_mem->cv_index ) break;
+    cvB_mem = cvB_mem->cv_next;
+  }
+
+  cvodeB_mem = (void *) (cvB_mem->cv_mem);
+
+  /* Initialize the BBD preconditioner */
+  flag = CVBBDPrecInit(cvodeB_mem, NlocalB, 
+                       mudqB, mldqB,
+                       mukeepB, mlkeepB, 
+                       dqrelyB, 
+                       cvGlocWrapper, cvCfnWrapper);
+
+  if (flag != CV_SUCCESS) return(flag);
+
+
+  /* Get memory for CVBBDPrecDataB to store the user-provided
+   * functions which will be called from the wrappers */
   cvbbdB_mem = NULL;
   cvbbdB_mem = (CVBBDPrecDataB) malloc(sizeof(* cvbbdB_mem));
   if (cvbbdB_mem == NULL) {
-    CVProcessError(cvB_mem, CVBBDPRE_MEM_FAIL, "CVBBDPRE", "CVBBDPrecAllocB", MSGBBDP_MEM_FAIL);
-    return(CVBBDPRE_MEM_FAIL);
+    cvProcessError(cv_mem, CVSPILS_MEM_FAIL, "CVBBDPRE", "CVBBDPrecInitB", MSGBBD_MEM_FAIL);
+    return(CVSPILS_MEM_FAIL);
   }
 
   gloc_B = glocB;
   cfn_B  = cfnB;
 
-  bbd_dataB = CVBBDPrecAlloc(cvB_mem, NlocalB, 
-                             mudqB, mldqB,
-                             mukeepB, mlkeepB, 
-                             dqrelyB, 
-                             CVAgloc, CVAcfn);
-  if (bbd_dataB == NULL) {
-    free(cvbbdB_mem); cvbbdB_mem = NULL;
-
-    return(CVBBDPRE_MEM_FAIL);
-  }
-
-  bbd_data_B = bbd_dataB;
-
-  /* attach pmemB */
-  pmemB = cvbbdB_mem;
-
-  return(CVBBDPRE_SUCCESS);
+  /* attach pmem and pfree */
+  cvB_mem->cv_pmem = cvbbdB_mem;
+  cvB_mem->cv_pfree = CVBBDPrecFreeB;
 
+  return(CVSPILS_SUCCESS);
 }
 
-int CVBBDSptfqmrB(void *cvadj_mem, int pretypeB, int maxlB)
+int CVBBDPrecReInitB(void *cvode_mem, int which, 
+                     long int mudqB, long int mldqB,
+                     realtype dqrelyB)
 {
-
+  CVodeMem cv_mem;
   CVadjMem ca_mem;
-  CVBBDPrecDataB cvbbdB_mem;
-  CVodeMem cvB_mem;
-  int flag;
-  
-  if (cvadj_mem == NULL) {
-    CVProcessError(NULL, CVBBDPRE_ADJMEM_NULL, "CVBBDPRE", "CVBBDSptfqmrB", MSGBBDP_CAMEM_NULL);
-    return(CVBBDPRE_ADJMEM_NULL);
-  }
-  ca_mem = (CVadjMem) cvadj_mem;
-  
-  cvB_mem = ca_mem->cvb_mem;
-  
-  if (pmemB == NULL) {
-    CVProcessError(cvB_mem, CVBBDPRE_PDATAB_NULL, "CVBBDPRE", "CVBBDSptfqmrB", MSGBBDP_PDATAB_NULL);
-    return(CVBBDPRE_PDATAB_NULL);
-  }
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
-
-  flag = CVBBDSptfqmr(cvB_mem, pretypeB, maxlB, bbd_data_B);
-
-  return(flag);
-
-}
-
-int CVBBDSpbcgB(void *cvadj_mem, int pretypeB, int maxlB)
-{
-
-  CVadjMem ca_mem;
-  CVBBDPrecDataB cvbbdB_mem;
-  CVodeMem cvB_mem;
-  int flag;
-  
-  if (cvadj_mem == NULL) {
-    CVProcessError(NULL, CVBBDPRE_ADJMEM_NULL, "CVBBDPRE", "CVBBDSpbcgB", MSGBBDP_CAMEM_NULL);
-    return(CVBBDPRE_ADJMEM_NULL);
-  }
-  ca_mem = (CVadjMem) cvadj_mem;
-  
-  cvB_mem = ca_mem->cvb_mem;
-  
-  if (pmemB == NULL) {
-    CVProcessError(cvB_mem, CVBBDPRE_PDATAB_NULL, "CVBBDPRE", "CVBBDSpbcgB", MSGBBDP_PDATAB_NULL);
-    return(CVBBDPRE_PDATAB_NULL);
-  }
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
-
-  flag = CVBBDSpbcg(cvB_mem, pretypeB, maxlB, bbd_data_B);
-
-  return(flag);
-
-}
-
-int CVBBDSpgmrB(void *cvadj_mem, int pretypeB, int maxlB)
-{
-
-  CVadjMem ca_mem;
-  CVBBDPrecDataB cvbbdB_mem;
-  CVodeMem cvB_mem;
-  int flag;
-  
-  if (cvadj_mem == NULL) {
-    CVProcessError(NULL, CVBBDPRE_ADJMEM_NULL, "CVBBDPRE", "CVBBDSpgmrB", MSGBBDP_CAMEM_NULL);
-    return(CV_ADJMEM_NULL);
-  }
-  ca_mem = (CVadjMem) cvadj_mem;
-  
-  cvB_mem = ca_mem->cvb_mem;
-  
-  if (pmemB == NULL) {
-    CVProcessError(cvB_mem, CVBBDPRE_PDATAB_NULL, "CVBBDPRE", "CVBBDSpgmrB", MSGBBDP_PDATAB_NULL);
-    return(CVBBDPRE_PDATAB_NULL);
-  }
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
-
-  flag = CVBBDSpgmr(cvB_mem, pretypeB, maxlB, bbd_data_B);
-
-  return(flag);
-
-}
-
-int CVBBDPrecReInitB(void *cvadj_mem, long int mudqB, long int mldqB,
-                     realtype dqrelyB, CVLocalFnB glocB, CVCommFnB cfnB)
-{
-  CVadjMem ca_mem;
-  CVodeMem cvB_mem;
-  CVBBDPrecDataB cvbbdB_mem;
+  CVodeBMem cvB_mem;
+  void *cvodeB_mem;
   int flag;
 
-  if (cvadj_mem == NULL) {
-    CVProcessError(NULL, CVBBDPRE_ADJMEM_NULL, "CVBBDPRE", "CVBBDPrecReInitB", MSGBBDP_CAMEM_NULL);
-    return(CVBBDPRE_ADJMEM_NULL);
+  /* Check if cvode_mem exists */
+  if (cvode_mem == NULL) {
+    cvProcessError(NULL, CVSPILS_MEM_NULL, "CVBBDPRE", "CVBBDPrecReInitB", MSGBBD_MEM_NULL);
+    return(CVSPILS_MEM_NULL);
   }
-  ca_mem = (CVadjMem) cvadj_mem;
+  cv_mem = (CVodeMem) cvode_mem;
+
+  /* Was ASA initialized? */
+  if (cv_mem->cv_adjMallocDone == FALSE) {
+    cvProcessError(cv_mem, CVSPILS_NO_ADJ, "CVBBDPRE", "CVBBDPrecReInitB", MSGBBD_NO_ADJ);
+    return(CVSPILS_NO_ADJ);
+  } 
+  ca_mem = cv_mem->cv_adj_mem;
+
+  /* Check which */
+  if ( which >= ca_mem->ca_nbckpbs ) {
+    cvProcessError(cv_mem, CVSPILS_ILL_INPUT, "CVBBDPRE", "CVBBDPrecReInitB", MSGBBD_BAD_WHICH);
+    return(CVSPILS_ILL_INPUT);
+  }
+
+  /* Find the CVodeBMem entry in the linked list corresponding to which */
+  cvB_mem = ca_mem->cvB_mem;
+  while (cvB_mem != NULL) {
+    if ( which == cvB_mem->cv_index ) break;
+    cvB_mem = cvB_mem->cv_next;
+  }
+
+  cvodeB_mem = (void *) (cvB_mem->cv_mem);
   
-  cvB_mem = ca_mem->cvb_mem;
-
-  if (pmemB == NULL) {
-    CVProcessError(cvB_mem, CVBBDPRE_PDATAB_NULL, "CVBBDPRE", "CVBBDPrecReInitB", MSGBBDP_PDATAB_NULL);
-    return(CVBBDPRE_PDATAB_NULL);
-  }
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
-
-  gloc_B = glocB;
-  cfn_B  = cfnB;
-
-  flag = CVBBDPrecReInit(bbd_data_B, mudqB, mldqB,
-                         dqrelyB, CVAgloc, CVAcfn);
+  flag = CVBBDPrecReInit(cvodeB_mem, mudqB, mldqB, dqrelyB);
 
   return(flag);
 }
 
 
-void CVBBDPrecFreeB(void *cvadj_mem)
+static void CVBBDPrecFreeB(CVodeBMem cvB_mem)
 {
-  CVadjMem ca_mem;
-  CVBBDPrecDataB cvbbdB_mem;
-
-  if (cvadj_mem == NULL) return;
-  ca_mem = (CVadjMem) cvadj_mem;
-  
-  if (pmemB == NULL) return;
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
-
-  CVBBDPrecFree(&bbd_data_B);
-  
-  free(pmemB); pmemB = NULL;
+  free(cvB_mem->cv_pmem); 
+  cvB_mem->cv_pmem = NULL;
 }
 
 
 /*
- * CVAgloc
+ * cvGlocWrapper
  *
  * This routine interfaces to the CVLocalFnB routine 
  * provided by the user.
- * NOTE: f_data actually contains cvadj_mem
  */
 
-static int CVAgloc(long int NlocalB, realtype t, N_Vector yB, N_Vector gB, 
-                   void *cvadj_mem)
+static int cvGlocWrapper(long int NlocalB, realtype t, N_Vector yB, N_Vector gB, void *cvode_mem)
 {
+  CVodeMem cv_mem;
   CVadjMem ca_mem;
-  CVodeMem cvB_mem;
+  CVodeBMem cvB_mem;
   CVBBDPrecDataB cvbbdB_mem;
   int retval, flag;
 
-  ca_mem = (CVadjMem) cvadj_mem;
-  cvB_mem = ca_mem->cvb_mem;
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
+  cv_mem = (CVodeMem) cvode_mem;
+
+  ca_mem = cv_mem->cv_adj_mem;
+
+  cvB_mem = ca_mem->ca_bckpbCrt;
+
+  cvbbdB_mem = (CVBBDPrecDataB) (cvB_mem->cv_pmem);
 
   /* Forward solution from interpolation */
-  flag = getY(ca_mem, t, ytmp);
+  flag = IMget(cv_mem, t, ytmp, NULL);
   if (flag != CV_SUCCESS) {
-    CVProcessError(cvB_mem, -1, "CVBBDPRE", "CVAgloc", MSGBBDP_BAD_T);
+    cvProcessError(cv_mem, -1, "CVBBDPRE", "cvGlocWrapper", MSGBBD_BAD_TINTERP);
     return(-1);
   } 
 
   /* Call user's adjoint glocB routine */
-  retval = gloc_B(NlocalB, t, ytmp, yB, gB, f_data_B);
+  retval = gloc_B(NlocalB, t, ytmp, yB, gB, cvB_mem->cv_user_data);
 
   return(retval);
 }
 
 /*
- * CVAcfn
+ * cvCfnWrapper
  *
  * This routine interfaces to the CVCommFnB routine 
  * provided by the user.
- * NOTE: f_data actually contains cvadj_mem
  */
 
-static int CVAcfn(long int NlocalB, realtype t, N_Vector yB,
-                  void *cvadj_mem)
+static int cvCfnWrapper(long int NlocalB, realtype t, N_Vector yB, void *cvode_mem)
 {
+  CVodeMem cv_mem;
   CVadjMem ca_mem;
-  CVodeMem cvB_mem;
+  CVodeBMem cvB_mem;
   CVBBDPrecDataB cvbbdB_mem;
   int retval, flag;
 
-  ca_mem = (CVadjMem) cvadj_mem;
-  cvB_mem = ca_mem->cvb_mem;
-  cvbbdB_mem = (CVBBDPrecDataB) pmemB;
+  cv_mem = (CVodeMem) cvode_mem;
+
+  ca_mem = cv_mem->cv_adj_mem;
+
+  cvB_mem = ca_mem->ca_bckpbCrt;
+
+  cvbbdB_mem = (CVBBDPrecDataB) (cvB_mem->cv_pmem);
 
   if (cfn_B == NULL) return(0);
 
   /* Forward solution from interpolation */
-  flag = getY(ca_mem, t, ytmp);
+  flag = IMget(cv_mem, t, ytmp, NULL);
   if (flag != CV_SUCCESS) {
-    CVProcessError(cvB_mem, -1, "CVBBDPRE", "CVAcfn", MSGBBDP_BAD_T);
+    cvProcessError(cv_mem, -1, "CVBBDPRE", "cvCfnWrapper", MSGBBD_BAD_TINTERP);
     return(-1);
   } 
 
   /* Call user's adjoint cfnB routine */
-  retval = cfn_B(NlocalB, t, ytmp, yB, f_data_B);
+  retval = cfn_B(NlocalB, t, ytmp, yB, cvB_mem->cv_user_data);
 
   return(retval);
 }
