@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.9 $
- * $Date: 2009/02/17 02:42:29 $
+ * $Revision: 1.11 $
+ * $Date: 2011/03/23 21:12:45 $
  * ----------------------------------------------------------------- 
  * Programmer(s): Alan C. Hindmarsh and Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -23,7 +23,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "idas_impl.h"
 #include "idas_spils_impl.h"
@@ -64,11 +63,11 @@ static int IBBDDQJac(IBBDPrecData pdata, realtype tt, realtype cj,
 
 /* Wrapper functions for adjoint code */
 
-static int IDAAglocal(int NlocalB, realtype tt,
+static int IDAAglocal(long int NlocalB, realtype tt,
                       N_Vector yyB, N_Vector ypB, N_Vector gvalB,
                       void *user_dataB);
 
-static int IDAAgcomm(int NlocalB, realtype tt,
+static int IDAAgcomm(long int NlocalB, realtype tt,
                      N_Vector yyB, N_Vector ypB,
                      void *user_dataB);
 
@@ -95,9 +94,9 @@ static void IDABBDPrecFreeB(IDABMem IDAB_mem);
  * -----------------------------------------------------------------
  */
 
-int IDABBDPrecInit(void *ida_mem, int Nlocal, 
-                   int mudq, int mldq, 
-                   int mukeep, int mlkeep, 
+int IDABBDPrecInit(void *ida_mem, long int Nlocal, 
+                   long int mudq, long int mldq, 
+                   long int mukeep, long int mlkeep, 
                    realtype dq_rel_yy, 
                    IDABBDLocalFn Gres, IDABBDCommFn Gcomm)
 {
@@ -105,7 +104,7 @@ int IDABBDPrecInit(void *ida_mem, int Nlocal,
   IDASpilsMem idaspils_mem;
   IBBDPrecData pdata;
   N_Vector tempv4;
-  int muk, mlk, storage_mu;
+  long int muk, mlk, storage_mu;
   int flag;
 
   if (ida_mem == NULL) {
@@ -158,10 +157,10 @@ int IDABBDPrecInit(void *ida_mem, int Nlocal,
     return(IDASPILS_MEM_FAIL); 
   }
 
-  /* Allocate memory for pivots. */
-  pdata->pivots = NULL;
-  pdata->pivots = NewIntArray(Nlocal);
-  if (pdata->PP == NULL) {
+  /* Allocate memory for lpivots. */
+  pdata->lpivots = NULL;
+  pdata->lpivots = NewLintArray(Nlocal);
+  if (pdata->lpivots == NULL) {
     DestroyMat(pdata->PP);
     free(pdata); pdata = NULL;
     IDAProcessError(IDA_mem, IDASPILS_MEM_FAIL, "IDABBDPRE", "IDABBDPrecInit", MSGBBD_MEM_FAIL);
@@ -173,7 +172,7 @@ int IDABBDPrecInit(void *ida_mem, int Nlocal,
   tempv4 = N_VClone(vec_tmpl); 
   if (tempv4 == NULL){
     DestroyMat(pdata->PP);
-    DestroyArray(pdata->pivots);
+    DestroyArray(pdata->lpivots);
     free(pdata); pdata = NULL;
     IDAProcessError(IDA_mem, IDASPILS_MEM_FAIL, "IDABBDPRE", "IDABBDPrecInit", MSGBBD_MEM_FAIL);
     return(IDASPILS_MEM_FAIL);
@@ -204,13 +203,13 @@ int IDABBDPrecInit(void *ida_mem, int Nlocal,
 }
 
 int IDABBDPrecReInit(void *ida_mem,
-		     int mudq, int mldq, 
+		     long int mudq, long int mldq, 
 		     realtype dq_rel_yy)
 {
   IDAMem IDA_mem;
   IDASpilsMem idaspils_mem;
   IBBDPrecData pdata;
-  int Nlocal;
+  long int Nlocal;
 
   if (ida_mem == NULL) {
     IDAProcessError(NULL, IDASPILS_MEM_NULL, "IDABBDPRE", "IDABBDPrecReInit", MSGBBD_MEM_NULL);
@@ -308,18 +307,18 @@ int IDABBDPrecGetNumGfnEvals(void *ida_mem, long int *ngevalsBBDP)
 
 /* Readability Replacements */
 
-#define Nlocal (pdata->n_local)
-#define mudq   (pdata->mudq)
-#define mldq   (pdata->mldq)
-#define mukeep (pdata->mukeep)
-#define mlkeep (pdata->mlkeep)
-#define glocal (pdata->glocal)
-#define gcomm  (pdata->gcomm)
-#define pivots (pdata->pivots)
-#define PP     (pdata->PP)
-#define tempv4 (pdata->tempv4)
-#define nge    (pdata->nge)
-#define rel_yy (pdata->rel_yy)
+#define Nlocal  (pdata->n_local)
+#define mudq    (pdata->mudq)
+#define mldq    (pdata->mldq)
+#define mukeep  (pdata->mukeep)
+#define mlkeep  (pdata->mlkeep)
+#define glocal  (pdata->glocal)
+#define gcomm   (pdata->gcomm)
+#define lpivots (pdata->lpivots)
+#define PP      (pdata->PP)
+#define tempv4  (pdata->tempv4)
+#define nge     (pdata->nge)
+#define rel_yy  (pdata->rel_yy)
 
 /*
  * -----------------------------------------------------------------
@@ -366,7 +365,8 @@ static int IDABBDPrecSetup(realtype tt,
                            realtype c_j, void *bbd_data,
                            N_Vector tempv1, N_Vector tempv2, N_Vector tempv3)
 {
-  int ier, retval;
+  int retval;
+  long int ier;
   IBBDPrecData pdata;
   IDAMem IDA_mem;
 
@@ -387,7 +387,7 @@ static int IDABBDPrecSetup(realtype tt,
   } 
  
   /* Do LU factorization of preconditioner block in place (in PP). */
-  ier = BandGBTRF(PP, pivots);
+  ier = BandGBTRF(PP, lpivots);
 
   /* Return 0 if the LU was complete, or +1 otherwise. */
   if (ier > 0) return(+1);
@@ -432,7 +432,7 @@ static int IDABBDPrecSolve(realtype tt,
 
   zd = N_VGetArrayPointer(zvec);
 
-  BandGBTRS(PP, pivots, zd);
+  BandGBTRS(PP, lpivots, zd);
 
   return(0);
 }
@@ -450,7 +450,7 @@ static void IDABBDPrecFree(IDAMem IDA_mem)
   pdata = (IBBDPrecData) idaspils_mem->s_pdata;
 
   DestroyMat(PP);
-  DestroyArray(pivots);
+  DestroyArray(lpivots);
   N_VDestroy(tempv4);
 
   free(pdata);
@@ -490,8 +490,8 @@ static int IBBDDQJac(IBBDPrecData pdata, realtype tt, realtype cj,
 {
   IDAMem IDA_mem;
   realtype inc, inc_inv;
-  int  retval;
-  int group, i, j, width, ngroups, i1, i2;
+  int retval;
+  long int group, i, j, width, ngroups, i1, i2;
   realtype *ydata, *ypdata, *ytempdata, *yptempdata, *grefdata, *gtempdata;
   realtype *cnsdata = NULL, *ewtdata;
   realtype *col_j, conj, yj, ypj, ewtj;
@@ -617,9 +617,9 @@ static int IBBDDQJac(IBBDPrecData pdata, realtype tt, realtype cj,
  * ----------------------------------------------------------------
  */
 
-int IDABBDPrecInitB(void *ida_mem, int which, int NlocalB,
-                     int mudqB, int mldqB,
-                     int mukeepB, int mlkeepB,
+int IDABBDPrecInitB(void *ida_mem, int which, long int NlocalB,
+                     long int mudqB, long int mldqB,
+                     long int mukeepB, long int mlkeepB,
                      realtype dq_rel_yyB,
                      IDABBDLocalFnB glocalB, IDABBDCommFnB gcommB)
 {
@@ -689,7 +689,8 @@ int IDABBDPrecInitB(void *ida_mem, int which, int NlocalB,
   return(IDASPILS_SUCCESS);
 }
 
-int IDABBDPrecReInitB(void *ida_mem, int which, int mudqB, int mldqB, realtype dq_rel_yyB)
+int IDABBDPrecReInitB(void *ida_mem, int which,
+                      long int mudqB, long int mldqB, realtype dq_rel_yyB)
 {
   IDAMem IDA_mem;
   IDAadjMem IDAADJ_mem;
@@ -750,7 +751,7 @@ static void IDABBDPrecFreeB(IDABMem IDAB_mem)
  * provided by the user.
  */
 
-static int IDAAglocal(int NlocalB, realtype tt,
+static int IDAAglocal(long int NlocalB, realtype tt,
                       N_Vector yyB, N_Vector ypB, N_Vector gvalB,
                       void *ida_mem)
 {
@@ -791,7 +792,7 @@ static int IDAAglocal(int NlocalB, realtype tt,
  * This routine interfaces to the IDACommFnB routine 
  * provided by the user.
  */
-static int IDAAgcomm(int NlocalB, realtype tt,
+static int IDAAgcomm(long int NlocalB, realtype tt,
                      N_Vector yyB, N_Vector ypB,
                      void *ida_mem)
 {
