@@ -1,10 +1,11 @@
-function [new_mondata] = cvm_monitor(call, t, y, yQ, Ns, yS, fct, mondata)
+function new_mondata = cvm_monitor(call, t, y, yQ, Ns, yS, fct, mondata)
 
 %
 % Wrapper around the actual user-provided Matlab function
 %
 
 N = length(y);
+
 yS = reshape(yS,N,Ns);
 
 if isempty(mondata)
