@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.22 $
- * $Date: 2007/12/05 21:58:18 $
+ * $Revision: 1.26 $
+ * $Date: 2012/03/07 21:48:00 $
  * -----------------------------------------------------------------
  * Programmer: Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -570,9 +570,9 @@ static int CVM_Initialization(int action, int nlhs, mxArray *plhs[], int nrhs, c
 
   booleantype rhs_s; /* ignored */
 
-  int mupper, mlower;
+  long int mupper, mlower;
   int ptype, gstype, maxl;
-  int mudq, mldq;
+  long int mudq, mldq;
   double dqrely;
 
   char *bufval;
@@ -952,17 +952,17 @@ static int CVM_Initialization(int action, int nlhs, mxArray *plhs[], int nrhs, c
 
   cvmData->errMsg = errmsg;
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -1120,17 +1120,17 @@ static int CVM_QuadInitialization(int action, int nlhs, mxArray *plhs[], int nrh
 
   quadr = TRUE;
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -1350,17 +1350,17 @@ static int CVM_SensInitialization(int action, int nlhs, mxArray *plhs[], int nrh
 
   fsa = TRUE;
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -1381,14 +1381,14 @@ static int CVM_SensToggleOff(int nlhs, mxArray *plhs[], int nrhs, const mxArray
   status = CVodeSensToggleOff(cvode_mem);
   if (status != CV_SUCCESS) {
     status = -1;
-    plhs[0] = mxCreateScalarDouble((double)status);
+    plhs[0] = mxCreateDoubleScalar((double)status);
     return(-1);
   }
 
   fsa = FALSE;
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 }
 
@@ -1452,17 +1452,17 @@ static int CVM_AdjInitialization(int action, int nlhs, mxArray *plhs[], int nrhs
 
   asa = TRUE;
   
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -1515,9 +1515,9 @@ static int CVM_InitializationB(int action, int nlhs, mxArray *plhs[], int nrhs,
 
   booleantype rhs_s;
 
-  int mupperB, mlowerB;
+  long int mupperB, mlowerB;
   int ptypeB, gstypeB, maxlB;
-  int mudqB, mldqB;
+  long int mudqB, mldqB;
   double dqrelyB;
 
   booleantype found_bck;
@@ -1724,7 +1724,7 @@ static int CVM_InitializationB(int action, int nlhs, mxArray *plhs[], int nrhs,
 
     /* Load idxB in the 1st output (status is 2nd one for this action) */
 
-    plhs[0] = mxCreateScalarDouble((double)idxB);
+    plhs[0] = mxCreateDoubleScalar((double)idxB);
 
     indexB = idxB;
 
@@ -1907,17 +1907,17 @@ static int CVM_InitializationB(int action, int nlhs, mxArray *plhs[], int nrhs,
 
   if (monB) mxW_CVodeMonitorB(0, idxB, tB0, NULL, NULL, bckPb);
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[i_status] = mxCreateScalarDouble((double)status);
+  plhs[i_status] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[i_status] = mxCreateScalarDouble((double)status);
+  plhs[i_status] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -2098,17 +2098,17 @@ static int CVM_QuadInitializationB(int action, int nlhs, mxArray *plhs[], int nr
 
   quadrB = TRUE;
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -2425,14 +2425,14 @@ static int CVM_Solve(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 
   /* CVODE return flag (only non-negative values make it here) */
 
-  plhs[0] = mxCreateScalarDouble((double)cv_status);
+  plhs[0] = mxCreateDoubleScalar((double)cv_status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   plhs[1] = mxCreateDoubleMatrix(0,0,mxREAL);
   plhs[2] = mxCreateDoubleMatrix(0,0,mxREAL);
   if (quadr) {
@@ -2585,7 +2585,7 @@ static int CVM_SolveB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   plhs[1] = mxCreateDoubleMatrix(0,0,mxREAL);
   plhs[2] = mxCreateDoubleMatrix(0,0,mxREAL);
   if (quadrB) {
@@ -2762,12 +2762,12 @@ static int cvmSolveB_one(mxArray *plhs[], int NtoutB, double *toutB, int itaskB)
 
   /* CVodeB return flag (only non-negative values make it here) */
 
-  plhs[0] = mxCreateScalarDouble((double)cv_status);
+  plhs[0] = mxCreateDoubleScalar((double)cv_status);
   return(0);
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   plhs[1] = mxCreateDoubleMatrix(0,0,mxREAL);
   plhs[2] = mxCreateDoubleMatrix(0,0,mxREAL);
   if (quadrB) {
@@ -2928,12 +2928,12 @@ static int cvmSolveB_more(mxArray *plhs[], int NtoutB, double *toutB, int itaskB
 
   /* CVODE return flag (only non-negative values make it here) */
 
-  plhs[0] = mxCreateScalarDouble((double)cv_status);
+  plhs[0] = mxCreateDoubleScalar((double)cv_status);
   return(0);
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   plhs[1] = mxCreateDoubleMatrix(0,0,mxREAL);
   plhs[2] = mxCreateDoubleMatrix(0,0,mxREAL);
   if (quadrB) {
@@ -3043,18 +3043,18 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   nfields = sizeof(fnames_intgr)/sizeof(*fnames_intgr);
   plhs[0] = mxCreateStructMatrix(1, 1, nfields, fnames_intgr);
  
-  mxSetField(plhs[0], 0, "nst",     mxCreateScalarDouble((double)nst));
-  mxSetField(plhs[0], 0, "nfe",     mxCreateScalarDouble((double)nfe));
-  mxSetField(plhs[0], 0, "nsetups", mxCreateScalarDouble((double)nsetups));
-  mxSetField(plhs[0], 0, "netf",    mxCreateScalarDouble((double)netf));
-  mxSetField(plhs[0], 0, "nni",     mxCreateScalarDouble((double)nni));
-  mxSetField(plhs[0], 0, "ncfn",    mxCreateScalarDouble((double)ncfn));
-  mxSetField(plhs[0], 0, "qlast",   mxCreateScalarDouble((double)qlast));
-  mxSetField(plhs[0], 0, "qcur",    mxCreateScalarDouble((double)qcur));
-  mxSetField(plhs[0], 0, "h0used",  mxCreateScalarDouble(h0used));
-  mxSetField(plhs[0], 0, "hlast",   mxCreateScalarDouble(hlast));
-  mxSetField(plhs[0], 0, "hcur",    mxCreateScalarDouble(hcur));
-  mxSetField(plhs[0], 0, "tcur",    mxCreateScalarDouble(tcur));
+  mxSetField(plhs[0], 0, "nst",     mxCreateDoubleScalar((double)nst));
+  mxSetField(plhs[0], 0, "nfe",     mxCreateDoubleScalar((double)nfe));
+  mxSetField(plhs[0], 0, "nsetups", mxCreateDoubleScalar((double)nsetups));
+  mxSetField(plhs[0], 0, "netf",    mxCreateDoubleScalar((double)netf));
+  mxSetField(plhs[0], 0, "nni",     mxCreateDoubleScalar((double)nni));
+  mxSetField(plhs[0], 0, "ncfn",    mxCreateDoubleScalar((double)ncfn));
+  mxSetField(plhs[0], 0, "qlast",   mxCreateDoubleScalar((double)qlast));
+  mxSetField(plhs[0], 0, "qcur",    mxCreateDoubleScalar((double)qcur));
+  mxSetField(plhs[0], 0, "h0used",  mxCreateDoubleScalar(h0used));
+  mxSetField(plhs[0], 0, "hlast",   mxCreateDoubleScalar(hlast));
+  mxSetField(plhs[0], 0, "hcur",    mxCreateDoubleScalar(hcur));
+  mxSetField(plhs[0], 0, "tcur",    mxCreateDoubleScalar(tcur));
 
 
   /* Root Finding Statistics */
@@ -3067,9 +3067,9 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     nfields = sizeof(fnames_root)/sizeof(*fnames_root);
     mxS_root = mxCreateStructMatrix(1, 1, nfields, fnames_root);
 
-    mxSetField(mxS_root, 0, "nge", mxCreateScalarDouble((double)nge));
+    mxSetField(mxS_root, 0, "nge", mxCreateDoubleScalar((double)nge));
 
-    rootsfound = (int *) malloc(nge*sizeof(int));
+    rootsfound = (int *) malloc(Ng*sizeof(int));
     status = CVodeGetRootInfo(cvode_mem, rootsfound);
     if (status != CV_SUCCESS) goto error_return;
     mxS_rootsfound = mxCreateDoubleMatrix(Ng,1,mxREAL);
@@ -3077,6 +3077,7 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     for (i=0;i<Ng;i++)
       tmp[i] = (double)rootsfound[i];
     mxSetField(mxS_root, 0, "roots", mxS_rootsfound);
+    free(rootsfound);
 
   } else {
 
@@ -3096,8 +3097,8 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     nfields = sizeof(fnames_quad)/sizeof(*fnames_quad);
     mxS_quad = mxCreateStructMatrix(1, 1, nfields, fnames_quad);
 
-    mxSetField(mxS_quad, 0, "nfQe",  mxCreateScalarDouble((double)nfQe));
-    mxSetField(mxS_quad, 0, "netfQ", mxCreateScalarDouble((double)netfQ));
+    mxSetField(mxS_quad, 0, "nfQe",  mxCreateDoubleScalar((double)nfQe));
+    mxSetField(mxS_quad, 0, "netfQ", mxCreateDoubleScalar((double)netfQ));
 
   } else {
 
@@ -3127,8 +3128,8 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     mxS_ls = mxCreateStructMatrix(1, 1, nfields, fnames_dense);
     
     mxSetField(mxS_ls, 0, "name", mxCreateString("Dense"));
-    mxSetField(mxS_ls, 0, "njeD", mxCreateScalarDouble((double)njeD));
-    mxSetField(mxS_ls, 0, "nfeD", mxCreateScalarDouble((double)nfeD));
+    mxSetField(mxS_ls, 0, "njeD", mxCreateDoubleScalar((double)njeD));
+    mxSetField(mxS_ls, 0, "nfeD", mxCreateDoubleScalar((double)nfeD));
     
     break;
 
@@ -3141,7 +3142,7 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     mxS_ls = mxCreateStructMatrix(1, 1, nfields, fnames_diag);
  
     mxSetField(mxS_ls, 0, "name", mxCreateString("Diag"));
-    mxSetField(mxS_ls, 0, "nfeDI", mxCreateScalarDouble((double)nfeDI));
+    mxSetField(mxS_ls, 0, "nfeDI", mxCreateDoubleScalar((double)nfeDI));
       
     break;
 
@@ -3156,8 +3157,8 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     mxS_ls = mxCreateStructMatrix(1, 1, nfields, fnames_band);
  
     mxSetField(mxS_ls, 0, "name", mxCreateString("Band"));
-    mxSetField(mxS_ls, 0, "njeB", mxCreateScalarDouble((double)njeB));
-    mxSetField(mxS_ls, 0, "nfeB", mxCreateScalarDouble((double)nfeB));
+    mxSetField(mxS_ls, 0, "njeB", mxCreateDoubleScalar((double)njeB));
+    mxSetField(mxS_ls, 0, "nfeB", mxCreateDoubleScalar((double)nfeB));
       
     break;
 
@@ -3188,12 +3189,12 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     else
       mxSetField(mxS_ls, 0, "name",  mxCreateString("TFQMR"));
 
-    mxSetField(mxS_ls, 0, "nli",   mxCreateScalarDouble((double)nli));
-    mxSetField(mxS_ls, 0, "npe",   mxCreateScalarDouble((double)npe));
-    mxSetField(mxS_ls, 0, "nps",   mxCreateScalarDouble((double)nps));
-    mxSetField(mxS_ls, 0, "ncfl",  mxCreateScalarDouble((double)ncfl));
-    mxSetField(mxS_ls, 0, "njeSG", mxCreateScalarDouble((double)njeSG));
-    mxSetField(mxS_ls, 0, "nfeSG", mxCreateScalarDouble((double)nfeSG));
+    mxSetField(mxS_ls, 0, "nli",   mxCreateDoubleScalar((double)nli));
+    mxSetField(mxS_ls, 0, "npe",   mxCreateDoubleScalar((double)npe));
+    mxSetField(mxS_ls, 0, "nps",   mxCreateDoubleScalar((double)nps));
+    mxSetField(mxS_ls, 0, "ncfl",  mxCreateDoubleScalar((double)ncfl));
+    mxSetField(mxS_ls, 0, "njeSG", mxCreateDoubleScalar((double)njeSG));
+    mxSetField(mxS_ls, 0, "nfeSG", mxCreateDoubleScalar((double)nfeSG));
     
     break;
     
@@ -3214,12 +3215,12 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     nfields = sizeof(fnames_sens)/sizeof(*fnames_sens);
     mxS_fsa = mxCreateStructMatrix(1, 1, nfields, fnames_sens);
     
-    mxSetField(mxS_fsa, 0, "nfSe",     mxCreateScalarDouble((double)nfSe));
-    mxSetField(mxS_fsa, 0, "nfeS",     mxCreateScalarDouble((double)nfeS));
-    mxSetField(mxS_fsa, 0, "nsetupsS", mxCreateScalarDouble((double)nsetupsS));
-    mxSetField(mxS_fsa, 0, "netfS",    mxCreateScalarDouble((double)netfS));
-    mxSetField(mxS_fsa, 0, "nniS",     mxCreateScalarDouble((double)nniS));
-    mxSetField(mxS_fsa, 0, "ncfnS",    mxCreateScalarDouble((double)ncfnS));
+    mxSetField(mxS_fsa, 0, "nfSe",     mxCreateDoubleScalar((double)nfSe));
+    mxSetField(mxS_fsa, 0, "nfeS",     mxCreateDoubleScalar((double)nfeS));
+    mxSetField(mxS_fsa, 0, "nsetupsS", mxCreateDoubleScalar((double)nsetupsS));
+    mxSetField(mxS_fsa, 0, "netfS",    mxCreateDoubleScalar((double)netfS));
+    mxSetField(mxS_fsa, 0, "nniS",     mxCreateDoubleScalar((double)nniS));
+    mxSetField(mxS_fsa, 0, "ncfnS",    mxCreateDoubleScalar((double)ncfnS));
     
   } else {
 
@@ -3229,17 +3230,17 @@ static int CVM_Stats(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   
   mxSetField(plhs[0], 0, "FSAInfo", mxS_fsa);
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[1] = mxCreateScalarDouble((double)status);
+  plhs[1] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[1] = mxCreateScalarDouble((double)status);
+  plhs[1] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -3345,18 +3346,18 @@ static int CVM_StatsB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
   nfields = sizeof(fnames_intgr)/sizeof(*fnames_intgr);
   plhs[0] = mxCreateStructMatrix(1, 1, nfields, fnames_intgr);
 
-  mxSetField(plhs[0], 0, "nst",     mxCreateScalarDouble((double)nst));
-  mxSetField(plhs[0], 0, "nfe",     mxCreateScalarDouble((double)nfe));
-  mxSetField(plhs[0], 0, "nsetups", mxCreateScalarDouble((double)nsetups));
-  mxSetField(plhs[0], 0, "netf",    mxCreateScalarDouble((double)netf));
-  mxSetField(plhs[0], 0, "nni",     mxCreateScalarDouble((double)nni));
-  mxSetField(plhs[0], 0, "ncfn",    mxCreateScalarDouble((double)ncfn));
-  mxSetField(plhs[0], 0, "qlast",   mxCreateScalarDouble((double)qlast));
-  mxSetField(plhs[0], 0, "qcur",    mxCreateScalarDouble((double)qcur));
-  mxSetField(plhs[0], 0, "h0used",  mxCreateScalarDouble(h0used));
-  mxSetField(plhs[0], 0, "hlast",   mxCreateScalarDouble(hlast));
-  mxSetField(plhs[0], 0, "hcur",    mxCreateScalarDouble(hcur));
-  mxSetField(plhs[0], 0, "tcur",    mxCreateScalarDouble(tcur));
+  mxSetField(plhs[0], 0, "nst",     mxCreateDoubleScalar((double)nst));
+  mxSetField(plhs[0], 0, "nfe",     mxCreateDoubleScalar((double)nfe));
+  mxSetField(plhs[0], 0, "nsetups", mxCreateDoubleScalar((double)nsetups));
+  mxSetField(plhs[0], 0, "netf",    mxCreateDoubleScalar((double)netf));
+  mxSetField(plhs[0], 0, "nni",     mxCreateDoubleScalar((double)nni));
+  mxSetField(plhs[0], 0, "ncfn",    mxCreateDoubleScalar((double)ncfn));
+  mxSetField(plhs[0], 0, "qlast",   mxCreateDoubleScalar((double)qlast));
+  mxSetField(plhs[0], 0, "qcur",    mxCreateDoubleScalar((double)qcur));
+  mxSetField(plhs[0], 0, "h0used",  mxCreateDoubleScalar(h0used));
+  mxSetField(plhs[0], 0, "hlast",   mxCreateDoubleScalar(hlast));
+  mxSetField(plhs[0], 0, "hcur",    mxCreateDoubleScalar(hcur));
+  mxSetField(plhs[0], 0, "tcur",    mxCreateDoubleScalar(tcur));
 
 
   /* Quadrature Statistics */
@@ -3369,8 +3370,8 @@ static int CVM_StatsB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
     nfields = sizeof(fnames_quad)/sizeof(*fnames_quad);
     mxS_quad = mxCreateStructMatrix(1, 1, nfields, fnames_quad);
 
-    mxSetField(mxS_quad, 0, "nfQe",  mxCreateScalarDouble((double)nfQe));
-    mxSetField(mxS_quad, 0, "netfQ", mxCreateScalarDouble((double)netfQ));
+    mxSetField(mxS_quad, 0, "nfQe",  mxCreateDoubleScalar((double)nfQe));
+    mxSetField(mxS_quad, 0, "netfQ", mxCreateDoubleScalar((double)netfQ));
 
   } else {
 
@@ -3400,8 +3401,8 @@ static int CVM_StatsB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
     mxS_ls = mxCreateStructMatrix(1, 1, nfields, fnames_dense);
 
     mxSetField(mxS_ls, 0, "name", mxCreateString("Dense"));
-    mxSetField(mxS_ls, 0, "njeD", mxCreateScalarDouble((double)njeD));
-    mxSetField(mxS_ls, 0, "nfeD", mxCreateScalarDouble((double)nfeD));
+    mxSetField(mxS_ls, 0, "njeD", mxCreateDoubleScalar((double)njeD));
+    mxSetField(mxS_ls, 0, "nfeD", mxCreateDoubleScalar((double)nfeD));
     
     break;
 
@@ -3414,7 +3415,7 @@ static int CVM_StatsB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
     mxS_ls = mxCreateStructMatrix(1, 1, nfields, fnames_diag);
  
     mxSetField(mxS_ls, 0, "name", mxCreateString("Diag"));
-    mxSetField(mxS_ls, 0, "nfeDI", mxCreateScalarDouble((double)nfeDI));
+    mxSetField(mxS_ls, 0, "nfeDI", mxCreateDoubleScalar((double)nfeDI));
       
     break;
 
@@ -3429,8 +3430,8 @@ static int CVM_StatsB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
     mxS_ls = mxCreateStructMatrix(1, 1, nfields, fnames_band);
  
     mxSetField(mxS_ls, 0, "name", mxCreateString("Band"));
-    mxSetField(mxS_ls, 0, "njeB", mxCreateScalarDouble((double)njeB));
-    mxSetField(mxS_ls, 0, "nfeB", mxCreateScalarDouble((double)nfeB));
+    mxSetField(mxS_ls, 0, "njeB", mxCreateDoubleScalar((double)njeB));
+    mxSetField(mxS_ls, 0, "nfeB", mxCreateDoubleScalar((double)nfeB));
       
     break;
 
@@ -3461,29 +3462,29 @@ static int CVM_StatsB(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
     else
       mxSetField(mxS_ls, 0, "name",  mxCreateString("TFQMR"));
 
-    mxSetField(mxS_ls, 0, "nli",   mxCreateScalarDouble((double)nli));
-    mxSetField(mxS_ls, 0, "npe",   mxCreateScalarDouble((double)npe));
-    mxSetField(mxS_ls, 0, "nps",   mxCreateScalarDouble((double)nps));
-    mxSetField(mxS_ls, 0, "ncfl",  mxCreateScalarDouble((double)ncfl));
-    mxSetField(mxS_ls, 0, "njeSG", mxCreateScalarDouble((double)njeSG));
-    mxSetField(mxS_ls, 0, "nfeSG", mxCreateScalarDouble((double)nfeSG));
+    mxSetField(mxS_ls, 0, "nli",   mxCreateDoubleScalar((double)nli));
+    mxSetField(mxS_ls, 0, "npe",   mxCreateDoubleScalar((double)npe));
+    mxSetField(mxS_ls, 0, "nps",   mxCreateDoubleScalar((double)nps));
+    mxSetField(mxS_ls, 0, "ncfl",  mxCreateDoubleScalar((double)ncfl));
+    mxSetField(mxS_ls, 0, "njeSG", mxCreateDoubleScalar((double)njeSG));
+    mxSetField(mxS_ls, 0, "nfeSG", mxCreateDoubleScalar((double)nfeSG));
     
     break;
   }
 
   mxSetField(plhs[0], 0, "LSInfo", mxS_ls);
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[1] = mxCreateScalarDouble((double)status);
+  plhs[1] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[1] = mxCreateScalarDouble((double)status);
+  plhs[1] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -3524,17 +3525,17 @@ static int CVM_Set(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     if (status != CV_SUCCESS) goto error_return;
   }
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[0] = mxCreateScalarDouble((double)status);
+  plhs[0] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
@@ -3603,34 +3604,37 @@ static int CVM_Get(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 
     ckpnt = (CVadjCheckPointRec *) malloc ( (Nc+1)*sizeof(CVadjCheckPointRec));
     status = CVodeGetAdjCheckPointsInfo(cvode_mem, ckpnt);
-    if (status != CV_SUCCESS) goto error_return;
+    if (status != CV_SUCCESS) {
+      free(ckpnt);
+      goto error_return;
+    }
     nfields = sizeof(fnames_ckpnt)/sizeof(*fnames_ckpnt);
     plhs[0] = mxCreateStructMatrix(Nc+1, 1, nfields, fnames_ckpnt);
     for (i=0; i<=Nc; i++) {
       this = (double *)(ckpnt[Nc-i].my_addr);
       next = (double *)(ckpnt[Nc-i].next_addr);
-      mxSetField(plhs[0], i, "t0",    mxCreateScalarDouble((double)(ckpnt[Nc-i].t0)));
-      mxSetField(plhs[0], i, "t1",    mxCreateScalarDouble((double)(ckpnt[Nc-i].t1)));
-      mxSetField(plhs[0], i, "nstep", mxCreateScalarDouble((double)(ckpnt[Nc-i].nstep)));
-      mxSetField(plhs[0], i, "order", mxCreateScalarDouble((double)(ckpnt[Nc-i].order)));
-      mxSetField(plhs[0], i, "step",  mxCreateScalarDouble((double)(ckpnt[Nc-i].step)));
+      mxSetField(plhs[0], i, "t0",    mxCreateDoubleScalar((double)(ckpnt[Nc-i].t0)));
+      mxSetField(plhs[0], i, "t1",    mxCreateDoubleScalar((double)(ckpnt[Nc-i].t1)));
+      mxSetField(plhs[0], i, "nstep", mxCreateDoubleScalar((double)(ckpnt[Nc-i].nstep)));
+      mxSetField(plhs[0], i, "order", mxCreateDoubleScalar((double)(ckpnt[Nc-i].order)));
+      mxSetField(plhs[0], i, "step",  mxCreateDoubleScalar((double)(ckpnt[Nc-i].step)));
     }
-
+    free(ckpnt);
     break;
 
   }
 
-  /* Successfull return */
+  /* Successful return */
 
   status = 0;
-  plhs[1] = mxCreateScalarDouble((double)status);
+  plhs[1] = mxCreateDoubleScalar((double)status);
   return(0);
 
   /* Error return */
 
  error_return:
   status = -1;
-  plhs[1] = mxCreateScalarDouble((double)status);
+  plhs[1] = mxCreateDoubleScalar((double)status);
   return(-1);
 
 }
