@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.12 $
- * $Date: 2007/12/05 21:58:18 $
+ * $Revision: 1.13 $
+ * $Date: 2012/03/07 21:44:21 $
  * -----------------------------------------------------------------
  * Programmer: Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -58,7 +58,8 @@ int get_IntgrOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd,
                      booleantype *rhs_s)
 {
   mxArray *opt;
-  int i, q, m, n;
+  int q;
+  long int i, m, n;
   double *tmp;
   char *fctName;
   char *fwd_fctName = "CVodeInit/CVodeReInit";
@@ -303,8 +304,8 @@ int get_IntgrOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd,
 
 
 int get_LinSolvOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd,
-                       int *mupper, int *mlower,
-                       int *mudq, int *mldq, double *dqrely,
+                       long int *mupper, long int *mlower,
+                       long int *mudq, long int *mldq, double *dqrely,
                        int *ptype, int *gstype, int *maxl)
 {
   mxArray *opt;
@@ -369,11 +370,11 @@ int get_LinSolvOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd
 
     opt = mxGetField(options,0,"UpperBwidth");
     if ( !mxIsEmpty(opt) )
-      *mupper = (int)*mxGetPr(opt);
+      *mupper = (long int)*mxGetPr(opt);
     
     opt = mxGetField(options,0,"LowerBwidth");
     if ( !mxIsEmpty(opt) )
-      *mlower = (int)*mxGetPr(opt);
+      *mlower = (long int)*mxGetPr(opt);
 
   }
 
@@ -476,11 +477,11 @@ int get_LinSolvOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd
     
       opt = mxGetField(options,0,"UpperBwidth");
       if ( !mxIsEmpty(opt) )
-        *mupper = (int)*mxGetPr(opt);
+        *mupper = (long int)*mxGetPr(opt);
       
       opt = mxGetField(options,0,"LowerBwidth");
       if ( !mxIsEmpty(opt) )
-        *mlower = (int)*mxGetPr(opt);
+        *mlower = (long int)*mxGetPr(opt);
       
     }
 
@@ -488,11 +489,11 @@ int get_LinSolvOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd
       
       opt = mxGetField(options,0,"UpperBwidthDQ");
       if ( !mxIsEmpty(opt) )
-        *mudq = (int)*mxGetPr(opt);
+        *mudq = (long int)*mxGetPr(opt);
 
       opt = mxGetField(options,0,"LowerBwidthDQ");
       if ( !mxIsEmpty(opt) )
-        *mldq = (int)*mxGetPr(opt);
+        *mldq = (long int)*mxGetPr(opt);
 
       opt = mxGetField(options,0,"GlocalFn");
       if ( !mxIsEmpty(opt) ) {
@@ -522,12 +523,12 @@ int get_LinSolvOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd
 
 
 int get_QuadOptions(const mxArray *options, cvmPbData thisPb, booleantype fwd,
-                    int Nq, booleantype *rhs_s,
+                    long int Nq, booleantype *rhs_s,
                     booleantype *errconQ,
                     int *itolQ, double *reltolQ, double *SabstolQ, double **VabstolQ)
 {
   mxArray *opt;
-  int i, m, n;
+  long int i, m, n;
   double *tmp;
   char *fctName;
   char *fwd_fctName = "CVodeQuadInit/CVodeQuadReInit";
