@@ -1,23 +1,35 @@
 function [] = install_STB
 %
-% INSTALL_STB Compilation of sundialsTB MEX files
+% INSTALL_STB Interactive compilation and installtion of sundialsTB
 
 % Radu Serban <radu@llnl.gov>
-% Copyright (c) 2005, The Regents of the University of California.
-% $Revision: 1.11 $Date: 2006/10/11 18:12:35 $
+% Copyright (c) 2007, The Regents of the University of California.
+% $Revision: 1.23 $Date: 2009/04/22 03:34:01 $
 
 % MEX compiler command
+% --------------------
 
-mexcompiler = 'mex';
+mexcompiler = 'mex -v';
 
 % Location of sundialsTB and top of sundials source tree
+% ------------------------------------------------------
 
 stb = pwd;
 cd('..');
 sun = pwd;
 cd(stb);
 
+% Test mex
+% --------
+
+mex_ok = check_mex(mexcompiler);
+
+if ~mex_ok
+  return
+end
+
 % Should we enable parallel support?
+% ----------------------------------
 
 par = true;
 if isempty(getenv('LAMHOME'))
@@ -31,34 +43,88 @@ if ~exist(q, 'dir')
     par = false;
 end
 
-% Create sundials_config.h
-mkdir('sundials');
-fi = fopen(fullfile('sundials','sundials_config.h'),'w');
-fprintf(fi,'#define SUNDIALS_PACKAGE_VERSION "2.3.0"\n');
-fprintf(fi,'#define SUNDIALS_DOUBLE_PRECISION 1\n');
-fprintf(fi,'#define SUNDIALS_USE_GENERIC_MATH 1\n');
-fclose(fi);
+% Figure out what modules exist and which ones will be built
+% ----------------------------------------------------------
 
-% Compile MEX file
+fprintf('\n\nSelect modules to be built\n');
 
-compile_CVM(mexcompiler,stb,sun,par);
-compile_IDM(mexcompiler,stb,sun,par);
-compile_KIM(mexcompiler,stb,sun,par);
+q = fullfile(sun,'src','cvodes');
+if exist(q, 'dir')
+  answ = input('    Compile CVODES interface? (y/n) ','s');
+  if answ == 'y'
+    cvm_ok = true;
+  else
+    cvm_ok = false;
+  end
+end
 
-% Remove sundials_config.h
+if exist(q, 'dir')
+  answ = input('    Compile IDAS interface? (y/n) ','s');
+  if answ == 'y'
+    idm_ok = true;
+  else
+    idm_ok = false;
+  end
+end
 
-rmdir('sundials','s');
+q = fullfile(sun,'src','kinsol');
+if exist(q, 'dir')
+  answ = input('    Compile KINSOL interface? (y/n) ','s');
+  if answ == 'y'
+    kim_ok = true;
+  else
+    kim_ok = false;
+  end
+end
 
-% Install sundialsTB
-
-ans = input('    Install toolbox? (y/n) ','s');
-if ans ~= 'y'
+if ~cvm_ok && ~idm_ok && ~kim_ok
   fprintf('\nOK. All done.\n');
   return
 end
 
+% Create sundials_config.h
+% ------------------------
+
+mkdir('sundials');
+fi = fopen(fullfile('sundials','sundials_config.h'),'w');
+fprintf(fi,'#define SUNDIALS_PACKAGE_VERSION "2.4.0"\n');
+fprintf(fi,'#define SUNDIALS_DOUBLE_PRECISION 1\n');
+fprintf(fi,'#define SUNDIALS_USE_GENERIC_MATH 1\n');
+fprintf(fi,'#define SUNDIALS_EXPORT\n');
+fclose(fi);
+
+% Compile MEX file for the selected modules
+% -----------------------------------------
+
+if cvm_ok
+  compile_CVM(mexcompiler,stb,sun,par);
+end
+
+if idm_ok
+  compile_IDM(mexcompiler,stb,sun,par);
+end
+  
+if kim_ok
+  compile_KIM(mexcompiler,stb,sun,par);
+end
+
+% Remove sundials_config.h
+% ------------------------
+
+rmdir('sundials','s');
+
+% Install sundialsTB
+% ------------------
+
+fprintf('\n\nMEX files were successfully created.\n');
+answ = input('    Install toolbox? (y/n) ','s');
+if answ ~= 'y'
+  fprintf('\n\nOK. All done.\n');
+  return
+end
+
 while true
-  fprintf('\nSpecify the location where you wish to install the toolbox.\n');
+  fprintf('\n\nSpecify the location where you wish to install the toolbox.\n');
   fprintf('The toolbox will be installed in a subdirectory "sundialsTB".\n');
   fprintf('Enter return to cancel the installation.\n');
   where = input('    Installation directory: ','s');
@@ -74,7 +140,7 @@ while true
 end
 
 if ~go
-  fprintf('\nOK. All done.\n');
+  fprintf('\n\nOK. All done.\n');
   return
 end
 
@@ -82,9 +148,9 @@ stbi = fullfile(where,'sundialsTB');
 
 go = 1;
 if exist(stbi,'dir')
-  fprintf('\nDirectory %s exists!\n',stbi);
-  ans = input('    Replace? (y/n) ','s');
-  if ans == 'y'
+  fprintf('\n\nDirectory %s exists!\n',stbi);
+  answ = input('    Replace? (y/n) ','s');
+  if answ == 'y'
     rmdir(stbi,'s');
     go = 1;
   else
@@ -93,36 +159,89 @@ if exist(stbi,'dir')
 end
 
 if ~go
-  fprintf('\nOK. All done.\n');
+  fprintf('\n\nOK. All done.\n');
   return
 end
 
 mkdir(where,'sundialsTB');
-mkdir(fullfile(where,'sundialsTB'),'cvodes');
-mkdir(fullfile(where,'sundialsTB','cvodes'),'cvm');
-mkdir(fullfile(where,'sundialsTB','cvodes'),'examples_ser');
-mkdir(fullfile(where,'sundialsTB'),'idas');
-mkdir(fullfile(where,'sundialsTB','idas'),'idm');
-mkdir(fullfile(where,'sundialsTB','idas'),'examples_ser');
-mkdir(fullfile(where,'sundialsTB'),'kinsol');
-mkdir(fullfile(where,'sundialsTB','kinsol'),'kim');
-mkdir(fullfile(where,'sundialsTB','kinsol'),'examples_ser');
 mkdir(fullfile(where,'sundialsTB'),'nvector');
 if par
   mkdir(fullfile(where,'sundialsTB'),'putils');
-  mkdir(fullfile(where,'sundialsTB','cvodes'),'examples_par');
-  mkdir(fullfile(where,'sundialsTB','idas'),'examples_par');
-  mkdir(fullfile(where,'sundialsTB','kinsol'),'examples_par');
 end
 
 instSTB(stb, where, par);
 
-fprintf('\nThe sundialsTB toolbox was installed in %s\n',stbi);
+if cvm_ok
+  mkdir(fullfile(where,'sundialsTB'),'cvodes');
+  mkdir(fullfile(where,'sundialsTB','cvodes'),'cvm');
+  mkdir(fullfile(where,'sundialsTB','cvodes'),'function_types');
+  mkdir(fullfile(where,'sundialsTB','cvodes'),'examples_ser');
+  if par
+    mkdir(fullfile(where,'sundialsTB','cvodes'),'examples_par');
+  end
+  instCVM(stb, where, par);
+end
+
+if idm_ok
+  mkdir(fullfile(where,'sundialsTB'),'idas');
+  mkdir(fullfile(where,'sundialsTB','idas'),'idm');
+  mkdir(fullfile(where,'sundialsTB','idas'),'function_types');
+  mkdir(fullfile(where,'sundialsTB','idas'),'examples_ser');
+  if par
+    mkdir(fullfile(where,'sundialsTB','idas'),'examples_par');
+  end
+  instIDM(stb, where, par);
+end
+
+if kim_ok
+  mkdir(fullfile(where,'sundialsTB'),'kinsol');
+  mkdir(fullfile(where,'sundialsTB','kinsol'),'kim');
+  mkdir(fullfile(where,'sundialsTB','kinsol'),'function_types');
+  mkdir(fullfile(where,'sundialsTB','kinsol'),'examples_ser');
+  if par
+    mkdir(fullfile(where,'sundialsTB','kinsol'),'examples_par');
+  end
+  instKIM(stb, where, par);
+end
+  
+fprintf('\n\nThe sundialsTB toolbox was installed in %s\n',stbi);
 fprintf('\nA startup file, "startup_STB.m" was created in %s.\n',stbi);
 fprintf('Use it as your Matlab startup file, or, if you already have a startup.m file,\n');
 fprintf('add a call to %s\n',fullfile(stbi,'startup_STB.m'));
 fprintf('\nEnjoy!\n\n');
 
+%---------------------------------------------------------------------------------
+% Check if mex works and if the user accepts the current mexopts
+%---------------------------------------------------------------------------------
+
+function mex_ok = check_mex(mexcompiler)
+
+% Create a dummy file
+fid = fopen('foo.c', 'w');
+fprintf(fid,'#include "mex.h"\n');
+fprintf(fid,'void mexFunction(int nlhs,mxArray *plhs[],int nrhs,const mxArray *prhs[])\n');
+fprintf(fid,'{return;}\n');
+fclose(fid);
+
+% Run mexcompiler on foo.c
+mex_cmd = sprintf('%s foo.c', mexcompiler);
+eval(mex_cmd);
+
+% Remove dummy source file and resulting mex file
+delete('foo.c')
+delete(sprintf('foo.%s', mexext))
+
+fprintf('\n\nMEX files will be compiled and built using the above options\n');
+answ = input('    Proceed? (y/n) ','s');
+if answ == 'y'
+  mex_ok = true;
+else
+  fprintf('\n\nOK. All done.\n');
+  mex_ok = false;
+end
+
+return
+
 %---------------------------------------------------------------------------------
 % compilation of cvm MEX file
 %---------------------------------------------------------------------------------
@@ -165,6 +284,7 @@ cvs_sources = {
     fullfile(sun,'src','cvodes','cvodes_band.c')
     fullfile(sun,'src','cvodes','cvodes_bandpre.c')
     fullfile(sun,'src','cvodes','cvodes_bbdpre.c')
+    fullfile(sun,'src','cvodes','cvodes_direct.c')
     fullfile(sun,'src','cvodes','cvodes_dense.c')
     fullfile(sun,'src','cvodes','cvodes_diag.c')
     fullfile(sun,'src','cvodes','cvodea.c')
@@ -181,7 +301,7 @@ shr_sources = {
     fullfile(sun,'src','sundials','sundials_dense.c')
     fullfile(sun,'src','sundials','sundials_iterative.c')
     fullfile(sun,'src','sundials','sundials_nvector.c')
-    fullfile(sun,'src','sundials','sundials_smalldense.c')
+    fullfile(sun,'src','sundials','sundials_direct.c')
     fullfile(sun,'src','sundials','sundials_spbcgs.c')
     fullfile(sun,'src','sundials','sundials_spgmr.c')
     fullfile(sun,'src','sundials','sundials_sptfqmr.c')
@@ -224,7 +344,7 @@ end
 
 cvm_dir = fullfile(stb,'cvodes','cvm');
 cd(cvm_dir)
-mex_cmd = sprintf('%s -v %s %s %s', mexcompiler, includes, sources, libraries);
+mex_cmd = sprintf('%s %s %s %s', mexcompiler, includes, sources, libraries);
 disp(mex_cmd);
 eval(mex_cmd);
 
@@ -271,25 +391,26 @@ libraries = '';
 % Add IDAS sources and header files
 
 ids_sources = {
-    fullfile(sun,'src','ida','ida_band.c')
-    fullfile(sun,'src','ida','ida_bbdpre.c')
-    fullfile(sun,'src','ida','ida_dense.c')
-%    fullfile(sun,'src','idas','idaa.c')
-    fullfile(sun,'src','ida','ida.c')
-    fullfile(sun,'src','ida','ida_ic.c')
-    fullfile(sun,'src','ida','ida_io.c')
-%    fullfile(sun,'src','idas','idaa_io.c')
-    fullfile(sun,'src','ida','ida_spils.c')
-    fullfile(sun,'src','ida','ida_spbcgs.c')
-    fullfile(sun,'src','ida','ida_spgmr.c')
-    fullfile(sun,'src','ida','ida_sptfqmr.c')
+    fullfile(sun,'src','idas','idas_band.c')
+    fullfile(sun,'src','idas','idas_bbdpre.c')
+    fullfile(sun,'src','idas','idas_dense.c')
+    fullfile(sun,'src','idas','idas_direct.c')
+    fullfile(sun,'src','idas','idaa.c')
+    fullfile(sun,'src','idas','idas.c')
+    fullfile(sun,'src','idas','idas_ic.c')
+    fullfile(sun,'src','idas','idas_io.c')
+    fullfile(sun,'src','idas','idaa_io.c')
+    fullfile(sun,'src','idas','idas_spils.c')
+    fullfile(sun,'src','idas','idas_spbcgs.c')
+    fullfile(sun,'src','idas','idas_spgmr.c')
+    fullfile(sun,'src','idas','idas_sptfqmr.c')
               };
 shr_sources = {
     fullfile(sun,'src','sundials','sundials_band.c')
     fullfile(sun,'src','sundials','sundials_dense.c')
     fullfile(sun,'src','sundials','sundials_iterative.c')
     fullfile(sun,'src','sundials','sundials_nvector.c')
-    fullfile(sun,'src','sundials','sundials_smalldense.c')
+    fullfile(sun,'src','sundials','sundials_direct.c')
     fullfile(sun,'src','sundials','sundials_spbcgs.c')
     fullfile(sun,'src','sundials','sundials_spgmr.c')
     fullfile(sun,'src','sundials','sundials_sptfqmr.c')
@@ -303,7 +424,7 @@ for i=1:length(shr_sources)
 end
 
 sun_incdir = fullfile(sun,'include');     % for SUNDIALS exported headers
-ids_srcdir = fullfile(sun,'src','ida');   % for idas_impl.h
+ids_srcdir = fullfile(sun,'src','idas');  % for idas_impl.h
 includes = sprintf('%s -I"%s" -I"%s"',includes,sun_incdir,ids_srcdir);
 
 % Add NVEC_SER sources and header files
@@ -332,7 +453,7 @@ end
 
 idm_dir = fullfile(stb,'idas','idm');
 cd(idm_dir)
-mex_cmd = sprintf('%s -v %s %s %s', mexcompiler, includes, sources, libraries);
+mex_cmd = sprintf('%s %s %s %s', mexcompiler, includes, sources, libraries);
 disp(mex_cmd);
 eval(mex_cmd);
 
@@ -383,6 +504,7 @@ kin_sources = {
     fullfile(sun,'src','kinsol','kinsol_band.c')
     fullfile(sun,'src','kinsol','kinsol_bbdpre.c')
     fullfile(sun,'src','kinsol','kinsol_dense.c')
+    fullfile(sun,'src','kinsol','kinsol_direct.c')
     fullfile(sun,'src','kinsol','kinsol.c')
     fullfile(sun,'src','kinsol','kinsol_io.c')
     fullfile(sun,'src','kinsol','kinsol_spils.c')
@@ -395,7 +517,7 @@ shr_sources = {
     fullfile(sun,'src','sundials','sundials_dense.c')
     fullfile(sun,'src','sundials','sundials_iterative.c')
     fullfile(sun,'src','sundials','sundials_nvector.c')
-    fullfile(sun,'src','sundials','sundials_smalldense.c')
+    fullfile(sun,'src','sundials','sundials_direct.c')
     fullfile(sun,'src','sundials','sundials_spbcgs.c')
     fullfile(sun,'src','sundials','sundials_spgmr.c')
     fullfile(sun,'src','sundials','sundials_sptfqmr.c')
@@ -439,7 +561,7 @@ end
 
 kim_dir = fullfile(stb, 'kinsol', 'kim');
 cd(kim_dir)
-mex_cmd = sprintf('%s -v %s %s %s', mexcompiler, includes, sources, libraries);
+mex_cmd = sprintf('%s %s %s %s', mexcompiler, includes, sources, libraries);
 disp(mex_cmd);
 eval(mex_cmd);
 
@@ -448,7 +570,7 @@ eval(mex_cmd);
 cd(stb)
 
 %---------------------------------------------------------------------------------
-% install sundialsTB
+% Installation of common sundialsTB files
 %---------------------------------------------------------------------------------
 
 function [] = instSTB(stb, where, par)
@@ -465,197 +587,18 @@ while(~feof(fi))
   l = fgets(fi);
   i = strfind(l,'@STB_PATH@');
   if ~isempty(i)
-    l = sprintf('stb_path = ''%s'';\n',where);
+    l = sprintf('  stb_path = ''%s'';\n',where);
   end
   fprintf(fo,'%s',l);
 end
 fclose(fo);
 fclose(fi);
 
-% Copy files to installation directory
-
-cvmmex = ['cvm.' mexext];
-idmmex = ['idm.' mexext];
-kimmex = ['kim.' mexext];
-
-cvm_files = {
+top_files = {
     'LICENSE'
     'Contents.m'
-    fullfile('cvodes','Contents.m')
-    fullfile('cvodes','CVadjMalloc.m')
-    fullfile('cvodes','CVBandJacFn.m')
-    fullfile('cvodes','CVDenseJacFn.m')
-    fullfile('cvodes','CVGcommFn.m')
-    fullfile('cvodes','CVGlocalFn.m')
-    fullfile('cvodes','CVJacTimesVecFn.m')
-    fullfile('cvodes','CVMonitorFn.m')
-    fullfile('cvodes','CVodeB.m')
-    fullfile('cvodes','CVodeFree.m')
-    fullfile('cvodes','CVodeGet.m')
-    fullfile('cvodes','CVodeGetStatsB.m')
-    fullfile('cvodes','CVodeGetStats.m')
-    fullfile('cvodes','CVode.m')
-    fullfile('cvodes','CVodeMallocB.m')
-    fullfile('cvodes','CVodeMalloc.m')
-    fullfile('cvodes','CVodeMonitor.m')
-    fullfile('cvodes','CVodeReInit.m')
-    fullfile('cvodes','CVodeReInitB.m')
-    fullfile('cvodes','CVodeSensMalloc.m')
-    fullfile('cvodes','CVodeSensToggleOff.m')
-    fullfile('cvodes','CVodeSensReInit.m')
-    fullfile('cvodes','CVodeSetFSAOptions.m')
-    fullfile('cvodes','CVodeSetOptions.m')
-    fullfile('cvodes','CVPrecSetupFn.m')
-    fullfile('cvodes','CVPrecSolveFn.m')
-    fullfile('cvodes','CVQuadRhsFn.m')
-    fullfile('cvodes','CVRhsFn.m')
-    fullfile('cvodes','CVRootFn.m')
-    fullfile('cvodes','CVSensRhsFn.m')
-    fullfile('cvodes','cvm','Contents.m')
-    fullfile('cvodes','cvm','cvm_bjac.m')
-    fullfile('cvodes','cvm','cvm_djac.m')
-    fullfile('cvodes','cvm','cvm_gcom.m')
-    fullfile('cvodes','cvm','cvm_gloc.m')
-    fullfile('cvodes','cvm','cvm_jtv.m')
-    fullfile('cvodes','cvm','cvm_monitor.m')
-    fullfile('cvodes','cvm','cvm_pset.m')
-    fullfile('cvodes','cvm','cvm_psol.m')
-    fullfile('cvodes','cvm','cvm_rhs.m')
-    fullfile('cvodes','cvm','cvm_rhsQ.m')
-    fullfile('cvodes','cvm','cvm_rhsS.m')
-    fullfile('cvodes','cvm','cvm_root.m')
-    fullfile('cvodes','cvm',cvmmex)    
             };
 
-cvm_exs = {
-    fullfile('cvodes','examples_ser','cvadx.m')
-    fullfile('cvodes','examples_ser','cvbx_f.m')
-    fullfile('cvodes','examples_ser','cvbx_J.m')
-    fullfile('cvodes','examples_ser','cvbx.m')
-    fullfile('cvodes','examples_ser','cvbx_q.m')
-    fullfile('cvodes','examples_ser','cvdiscx.m')
-    fullfile('cvodes','examples_ser','cvdx_fB.m')
-    fullfile('cvodes','examples_ser','cvdx_f.m')
-    fullfile('cvodes','examples_ser','cvdx_fS.m')
-    fullfile('cvodes','examples_ser','cvdx_g.m')
-    fullfile('cvodes','examples_ser','cvdx_JB.m')
-    fullfile('cvodes','examples_ser','cvdx_J.m')
-    fullfile('cvodes','examples_ser','cvdx.m')
-    fullfile('cvodes','examples_ser','cvdx_qB.m')
-    fullfile('cvodes','examples_ser','cvdx_q.m')
-    fullfile('cvodes','examples_ser','cvfdx.m')
-    fullfile('cvodes','examples_ser','cvkxb.m')
-    fullfile('cvodes','examples_ser','cvkx_f.m')
-    fullfile('cvodes','examples_ser','cvkx.m')
-    fullfile('cvodes','examples_ser','cvkx_pset.m')
-    fullfile('cvodes','examples_ser','cvkx_psol.m')
-    fullfile('cvodes','examples_ser','pleiades_f.m')
-    fullfile('cvodes','examples_ser','pleiades_J.m')
-    fullfile('cvodes','examples_ser','pleiades.m')
-    fullfile('cvodes','examples_ser','vdp_f.m')
-    fullfile('cvodes','examples_ser','vdp_J.m')
-    fullfile('cvodes','examples_ser','vdp.m')
-          };
-
-cvm_exp = {
-    fullfile('cvodes','examples_par','pvfnx_f.m')
-    fullfile('cvodes','examples_par','pvfnx.m')
-    fullfile('cvodes','examples_par','pvkx_fl.m')
-    fullfile('cvodes','examples_par','pvkx_f.m')
-    fullfile('cvodes','examples_par','pvkx.m')
-    fullfile('cvodes','examples_par','pvnx_f.m')
-    fullfile('cvodes','examples_par','pvnx.m')    
-          };
-
-idm_files = {
-    fullfile('idas','Contents.m')
-    fullfile('idas','IDABandJacFn.m')
-    fullfile('idas','IDACalcIC.m')
-    fullfile('idas','IDADenseJacFn.m')
-    fullfile('idas','IDAGcommFn.m')
-    fullfile('idas','IDAGlocalFn.m')
-    fullfile('idas','IDAJacTimesVecFn.m')
-    fullfile('idas','IDAMonitorFn.m')
-    fullfile('idas','IDAFree.m')
-    fullfile('idas','IDAGet.m')
-    fullfile('idas','IDAGetStats.m')
-    fullfile('idas','IDASolve.m')
-    fullfile('idas','IDAMalloc.m')
-    fullfile('idas','IDAMonitor.m')
-    fullfile('idas','IDASetOptions.m')
-    fullfile('idas','IDAPrecSetupFn.m')
-    fullfile('idas','IDAPrecSolveFn.m')
-    fullfile('idas','IDAResFn.m')
-    fullfile('idas','IDARootFn.m')
-    fullfile('idas','idm','Contents.m')
-    fullfile('idas','idm','idm_bjac.m')
-    fullfile('idas','idm','idm_djac.m')
-    fullfile('idas','idm','idm_gcom.m')
-    fullfile('idas','idm','idm_gloc.m')
-    fullfile('idas','idm','idm_jtv.m')
-    fullfile('idas','idm','idm_monitor.m')
-    fullfile('idas','idm','idm_pset.m')
-    fullfile('idas','idm','idm_psol.m')
-    fullfile('idas','idm','idm_res.m')
-    fullfile('idas','idm','idm_root.m')
-    fullfile('idas','idm',idmmex)    
-            };
-
-idm_exs = {
-    fullfile('idas','examples_ser','idabanx.m')
-    fullfile('idas','examples_ser','idabanx_ic.m')
-    fullfile('idas','examples_ser','idabanx_f.m')
-    fullfile('idas','examples_ser','idadenx.m')
-    fullfile('idas','examples_ser','idadenx_f.m')
-    fullfile('idas','examples_ser','idadenx_g.m')
-    fullfile('idas','examples_ser','pend.m')
-    fullfile('idas','examples_ser','pendGGL.m')
-          };
-
-kim_files = {
-    fullfile('kinsol','Contents.m')
-    fullfile('kinsol','KINBandJacFn.m')
-    fullfile('kinsol','KINDenseJacFn.m')
-    fullfile('kinsol','KINFree.m')
-    fullfile('kinsol','KINGcommFn.m')
-    fullfile('kinsol','KINGetStats.m')
-    fullfile('kinsol','KINGlocalFn.m')
-    fullfile('kinsol','KINJacTimesVecFn.m')
-    fullfile('kinsol','KINMalloc.m')
-    fullfile('kinsol','KINPrecSetupFn.m')
-    fullfile('kinsol','KINPrecSolveFn.m')
-    fullfile('kinsol','KINSetOptions.m')
-    fullfile('kinsol','KINSol.m')
-    fullfile('kinsol','KINSysFn.m')
-    fullfile('kinsol','kim','Contents.m')
-    fullfile('kinsol','kim','kim_bjac.m')
-    fullfile('kinsol','kim','kim_djac.m')
-    fullfile('kinsol','kim','kim_gcom.m')
-    fullfile('kinsol','kim','kim_gloc.m')
-    fullfile('kinsol','kim','kim_info.m')
-    fullfile('kinsol','kim','kim_jtv.m')
-    fullfile('kinsol','kim','kim_pset.m')
-    fullfile('kinsol','kim','kim_psol.m')
-    fullfile('kinsol','kim','kim_sys.m')
-    fullfile('kinsol','kim',kimmex)
-            };
-
-kim_exs = {
-    fullfile('kinsol','examples_ser','kindiag.m')
-    fullfile('kinsol','examples_ser','kindiag_pset.m')
-    fullfile('kinsol','examples_ser','kindiag_psol.m')
-    fullfile('kinsol','examples_ser','kindiag_sys.m')
-    fullfile('kinsol','examples_ser','kindx.m')
-    fullfile('kinsol','examples_ser','kindx_sys.m')
-          };
-
-kim_exp = {
-    fullfile('kinsol','examples_par','kindiagp.m')
-    fullfile('kinsol','examples_par','kindiagp_pset.m')
-    fullfile('kinsol','examples_par','kindiagp_psol.m')
-    fullfile('kinsol','examples_par','kindiagp_sys.m') 
-          };
-
 nvm_files = {
     fullfile('nvector','Contents.m')
     fullfile('nvector','N_VDotProd.m')
@@ -674,9 +617,9 @@ put_files = {
     fullfile('putils','mpiruns.m')    
             };
 
-stb_files = [cvm_files; idm_files; kim_files; nvm_files; cvm_exs; idm_exs; kim_exs];
+stb_files = [top_files ; nvm_files];
 if par
-  stb_files = [stb_files ; put_files ; cvm_exp ; kim_exp];
+  stb_files = [stb_files; put_files];
 end
 
 fprintf('\n\n');
@@ -690,3 +633,393 @@ for i=1:length(stb_files)
     break;
   end
 end
+
+%---------------------------------------------------------------------------------
+% Installation of CVODES files
+%---------------------------------------------------------------------------------
+
+function [] = instCVM(stb, where, par)
+
+stbi = fullfile(where,'sundialsTB');
+
+% Copy files to installation directory
+
+cvmmex = ['cvm.' mexext];
+
+cvm_files = {
+    fullfile('cvodes','Contents.m')
+%
+    fullfile('cvodes','CVodeSetOptions.m')
+    fullfile('cvodes','CVodeQuadSetOptions.m')
+    fullfile('cvodes','CVodeSensSetOptions.m')
+    fullfile('cvodes','CVodeInit.m')
+    fullfile('cvodes','CVodeReInit.m')
+    fullfile('cvodes','CVodeQuadInit.m')
+    fullfile('cvodes','CVodeQuadReInit.m')
+    fullfile('cvodes','CVodeSensInit.m')
+    fullfile('cvodes','CVodeSensReInit.m')
+    fullfile('cvodes','CVode.m')
+    fullfile('cvodes','CVodeGet.m')
+    fullfile('cvodes','CVodeSet.m')
+    fullfile('cvodes','CVodeGetStats.m')
+%
+    fullfile('cvodes','CVodeAdjInit.m')
+    fullfile('cvodes','CVodeAdjReInit.m')
+%
+    fullfile('cvodes','CVodeInitB.m')
+    fullfile('cvodes','CVodeReInitB.m')
+    fullfile('cvodes','CVodeQuadInitB.m')
+    fullfile('cvodes','CVodeQuadReInitB.m')
+    fullfile('cvodes','CVodeSensToggleOff.m')
+    fullfile('cvodes','CVodeB.m')
+    fullfile('cvodes','CVodeSetB.m')
+    fullfile('cvodes','CVodeGetStatsB.m')
+%
+    fullfile('cvodes','CVodeFree.m')
+%
+    fullfile('cvodes','cvm','Contents.m')
+    fullfile('cvodes','cvm','cvm_options.m')
+%
+    fullfile('cvodes','cvm','cvm_rhs.m')
+    fullfile('cvodes','cvm','cvm_rhsQ.m')
+    fullfile('cvodes','cvm','cvm_rhsS.m')
+    fullfile('cvodes','cvm','cvm_root.m')
+    fullfile('cvodes','cvm','cvm_bjac.m')
+    fullfile('cvodes','cvm','cvm_djac.m')
+    fullfile('cvodes','cvm','cvm_jtv.m')
+    fullfile('cvodes','cvm','cvm_pset.m')
+    fullfile('cvodes','cvm','cvm_psol.m')
+    fullfile('cvodes','cvm','cvm_gcom.m')
+    fullfile('cvodes','cvm','cvm_gloc.m')
+    fullfile('cvodes','cvm','cvm_monitor.m')
+%
+    fullfile('cvodes','cvm','cvm_rhsB.m')
+    fullfile('cvodes','cvm','cvm_rhsQB.m')
+    fullfile('cvodes','cvm','cvm_bjacB.m')
+    fullfile('cvodes','cvm','cvm_djacB.m')
+    fullfile('cvodes','cvm','cvm_jtvB.m')
+    fullfile('cvodes','cvm','cvm_psetB.m')
+    fullfile('cvodes','cvm','cvm_psolB.m')
+    fullfile('cvodes','cvm','cvm_gcomB.m')
+    fullfile('cvodes','cvm','cvm_glocB.m')
+    fullfile('cvodes','cvm','cvm_monitorB.m')
+%
+    fullfile('cvodes','cvm',cvmmex)    
+            };
+
+cvm_ftypes = {
+    fullfile('cvodes','function_types','CVRhsFn.m')
+    fullfile('cvodes','function_types','CVQuadRhsFn.m')
+    fullfile('cvodes','function_types','CVSensRhsFn.m')
+    fullfile('cvodes','function_types','CVRootFn.m')
+    fullfile('cvodes','function_types','CVBandJacFn.m')
+    fullfile('cvodes','function_types','CVDenseJacFn.m')
+    fullfile('cvodes','function_types','CVJacTimesVecFn.m')
+    fullfile('cvodes','function_types','CVPrecSetupFn.m')
+    fullfile('cvodes','function_types','CVPrecSolveFn.m')
+    fullfile('cvodes','function_types','CVGcommFn.m')
+    fullfile('cvodes','function_types','CVGlocalFn.m')
+    fullfile('cvodes','function_types','CVMonitorFn.m')
+%
+    fullfile('cvodes','function_types','CVRhsFnB.m')
+    fullfile('cvodes','function_types','CVQuadRhsFnB.m')
+    fullfile('cvodes','function_types','CVBandJacFnB.m')
+    fullfile('cvodes','function_types','CVDenseJacFnB.m')
+    fullfile('cvodes','function_types','CVJacTimesVecFnB.m')
+    fullfile('cvodes','function_types','CVPrecSetupFnB.m')
+    fullfile('cvodes','function_types','CVPrecSolveFnB.m')
+    fullfile('cvodes','function_types','CVGcommFnB.m')
+    fullfile('cvodes','function_types','CVGlocalFnB.m')
+    fullfile('cvodes','function_types','CVMonitorFnB.m')
+             };    
+
+cvm_exs = {
+    fullfile('cvodes','examples_ser','mcvsAdvDiff_bnd.m')
+    fullfile('cvodes','examples_ser','mcvsDiscRHS_dns.m')
+    fullfile('cvodes','examples_ser','mcvsDiscSOL_dns.m')
+    fullfile('cvodes','examples_ser','mcvsDiurnal_kry.m')
+    fullfile('cvodes','examples_ser','mcvsHessian_FSA_ASA.m')
+    fullfile('cvodes','examples_ser','mcvsOzone_FSA_dns.m')
+    fullfile('cvodes','examples_ser','mcvsPleiades_non.m')
+    fullfile('cvodes','examples_ser','mcvsPollut_FSA_dns.m')
+    fullfile('cvodes','examples_ser','mcvsRoberts_ASAi_dns.m')
+    fullfile('cvodes','examples_ser','mcvsRoberts_dns.m')
+    fullfile('cvodes','examples_ser','mcvsRoberts_FSA_dns.m')
+    fullfile('cvodes','examples_ser','mcvsVanDPol_dns.m')
+          };
+
+cvm_exp = {
+    fullfile('cvodes','examples_par','mcvsAdvDiff_FSA_non_p.m')
+    fullfile('cvodes','examples_par','mcvsAtmDisp_kry_bbd_p.m')
+    fullfile('cvodes','examples_par','mcvsDecoupl_non_p.m')
+          };
+
+stb_files = [cvm_files ; cvm_ftypes ; cvm_exs];
+if par
+  stb_files = [stb_files ; cvm_exp];
+end
+
+fprintf('\n\n');
+for i=1:length(stb_files)
+  src = fullfile(stb,stb_files{i});
+  dest = fullfile(stbi,stb_files{i});
+  fprintf('Install %s\n',dest);
+  [success,msg,msgid] = copyfile(src,dest);
+  if ~success
+    disp(msg);
+    break;
+  end
+end
+
+if (exist ('OCTAVE_VERSION'))
+  cvmon = fullfile('cvodes','CVodeMonitor_octave.m');
+  cvmonB = fullfile('cvodes','CVodeMonitorB_octave.m');
+else
+  cvmon = fullfile('cvodes','CVodeMonitor.m');
+  cvmonB = fullfile('cvodes','CVodeMonitorB.m');
+end
+
+src = fullfile(stb,cvmon);
+dest = fullfile(stbi,'cvodes','CVodeMonitor.m');
+fprintf('Install %s\n',dest);
+[success,msg,msgid] = copyfile(src,dest);
+if ~success
+  disp(msg);
+end
+
+src = fullfile(stb,cvmonB);
+dest = fullfile(stbi,'cvodes','CVodeMonitorB.m');
+fprintf('Install %s\n',dest);
+[success,msg,msgid] = copyfile(src,dest);
+if ~success
+  disp(msg);
+end
+
+%---------------------------------------------------------------------------------
+% Installation of IDAS files
+%---------------------------------------------------------------------------------
+
+function [] = instIDM(stb, where, par)
+
+stbi = fullfile(where,'sundialsTB');
+
+% Copy files to installation directory
+
+idmmex = ['idm.' mexext];
+
+idm_files = {
+    fullfile('idas','Contents.m')
+%
+    fullfile('idas','IDASetOptions.m')
+    fullfile('idas','IDAQuadSetOptions.m')
+    fullfile('idas','IDASensSetOptions.m')
+    fullfile('idas','IDAInit.m')
+    fullfile('idas','IDAReInit.m')
+    fullfile('idas','IDAQuadInit.m')
+    fullfile('idas','IDAQuadReInit.m')
+    fullfile('idas','IDASensInit.m')
+    fullfile('idas','IDASensReInit.m')
+    fullfile('idas','IDASensToggleOff.m')
+    fullfile('idas','IDAAdjReInit.m')
+    fullfile('idas','IDACalcIC.m')
+    fullfile('idas','IDASolve.m')
+    fullfile('idas','IDASet.m')
+    fullfile('idas','IDAGet.m')
+    fullfile('idas','IDAGetStats.m')
+%
+    fullfile('idas','IDAAdjInit.m')
+%
+    fullfile('idas','IDAInitB.m')
+    fullfile('idas','IDAReInitB.m')
+    fullfile('idas','IDAQuadInitB.m')
+    fullfile('idas','IDAQuadReInitB.m')
+    fullfile('idas','IDACalcICB.m')
+    fullfile('idas','IDASolveB.m')
+    fullfile('idas','IDASetB.m')
+    fullfile('idas','IDAGetStatsB.m')
+%
+    fullfile('idas','IDAFree.m')
+%
+    fullfile('idas','idm','Contents.m')
+    fullfile('idas','idm','idm_options.m')
+%
+    fullfile('idas','idm','idm_res.m')
+    fullfile('idas','idm','idm_rhsQ.m')
+    fullfile('idas','idm','idm_bjac.m')
+    fullfile('idas','idm','idm_djac.m')
+    fullfile('idas','idm','idm_gcom.m')
+    fullfile('idas','idm','idm_gloc.m')
+    fullfile('idas','idm','idm_jtv.m')
+    fullfile('idas','idm','idm_pset.m')
+    fullfile('idas','idm','idm_psol.m')
+    fullfile('idas','idm','idm_root.m')
+    fullfile('idas','idm','idm_resS.m')
+    fullfile('idas','idm','idm_monitor.m')
+%
+    fullfile('idas','idm','idm_resB.m')
+    fullfile('idas','idm','idm_rhsQB.m')
+    fullfile('idas','idm','idm_bjacB.m')
+    fullfile('idas','idm','idm_djacB.m')
+    fullfile('idas','idm','idm_jtvB.m')
+    fullfile('idas','idm','idm_psetB.m')
+    fullfile('idas','idm','idm_psolB.m')
+    fullfile('idas','idm','idm_gcomB.m')
+    fullfile('idas','idm','idm_glocB.m')
+    fullfile('idas','idm','idm_monitorB.m')
+%
+    fullfile('idas','idm',idmmex)    
+            };
+
+idm_ftypes = {
+    fullfile('idas','function_types','IDABandJacFn.m')
+    fullfile('idas','function_types','IDABandJacFnB.m')
+    fullfile('idas','function_types','IDADenseJacFn.m')
+    fullfile('idas','function_types','IDADenseJacFnB.m')
+    fullfile('idas','function_types','IDAGcommFn.m')
+    fullfile('idas','function_types','IDAGcommFnB.m')
+    fullfile('idas','function_types','IDAGlocalFn.m')
+    fullfile('idas','function_types','IDAGlocalFnB.m')
+    fullfile('idas','function_types','IDAJacTimesVecFn.m')
+    fullfile('idas','function_types','IDAJacTimesVecFnB.m')
+    fullfile('idas','function_types','IDAMonitorFn.m')
+    fullfile('idas','function_types','IDAMonitorFnB.m')
+    fullfile('idas','function_types','IDAPrecSetupFn.m')
+    fullfile('idas','function_types','IDAPrecSetupFnB.m')
+    fullfile('idas','function_types','IDAPrecSolveFn.m')
+    fullfile('idas','function_types','IDAPrecSolveFnB.m')
+    fullfile('idas','function_types','IDAQuadRhsFn.m')
+    fullfile('idas','function_types','IDAQuadRhsFnB.m')
+    fullfile('idas','function_types','IDAResFn.m')
+    fullfile('idas','function_types','IDAResFnB.m')
+    fullfile('idas','function_types','IDARootFn.m')
+    fullfile('idas','function_types','IDASensResFn.m')
+             };
+
+idm_exs = {
+    fullfile('idas','examples_ser','midasBruss_ASA_dns.m')
+    fullfile('idas','examples_ser','midasBruss_dns.m')
+    fullfile('idas','examples_ser','midasHeat2D_bnd.m')
+    fullfile('idas','examples_ser','midasPendI1_dns.m')
+    fullfile('idas','examples_ser','midasPendI2_dns.m')
+    fullfile('idas','examples_ser','midasReInit_dns.m')
+    fullfile('idas','examples_ser','midasRoberts_ASAi_dns.m')
+    fullfile('idas','examples_ser','midasRoberts_dns.m')
+    fullfile('idas','examples_ser','midasSlCrank_dns.m')
+    fullfile('idas','examples_ser','midasSlCrank_FSA_dns.m')
+          };
+
+stb_files = [idm_files ; idm_ftypes ; idm_exs];
+%if par
+%  stb_files = [stb_files ; idm_exp];
+%end
+
+fprintf('\n\n');
+for i=1:length(stb_files)
+  src = fullfile(stb,stb_files{i});
+  dest = fullfile(stbi,stb_files{i});
+  fprintf('Install %s\n',dest);
+  [success,msg,msgid] = copyfile(src,dest);
+  if ~success
+    disp(msg);
+    break;
+  end
+end
+
+if (exist ('OCTAVE_VERSION'))
+  idamon = fullfile('idas','IDAMonitor_octave.m');
+  idamonB = fullfile('idas','IDAMonitorB_octave.m');
+else
+  idamon = fullfile('idas','IDAMonitor.m');
+  idamonB = fullfile('idas','IDAMonitorB.m');
+end
+
+src = fullfile(stb,idamon);
+dest = fullfile(stbi,'idas','IDAMonitor.m');
+fprintf('Install %s\n',dest);
+[success,msg,msgid] = copyfile(src,dest);
+if ~success
+  disp(msg);
+end
+
+src = fullfile(stb,idamonB);
+dest = fullfile(stbi,'idas','IDAMonitorB.m');
+fprintf('Install %s\n',dest);
+[success,msg,msgid] = copyfile(src,dest);
+if ~success
+  disp(msg);
+end
+
+
+
+%---------------------------------------------------------------------------------
+% Installation of KINSOL files
+%---------------------------------------------------------------------------------
+
+function [] = instKIM(stb, where, par)
+
+stbi = fullfile(where,'sundialsTB');
+
+% Copy files to installation directory
+
+kimmex = ['kim.' mexext];
+
+kim_files = {
+    fullfile('kinsol','Contents.m')
+    fullfile('kinsol','KINFree.m')
+    fullfile('kinsol','KINGetStats.m')
+    fullfile('kinsol','KINInit.m')
+    fullfile('kinsol','KINSetOptions.m')
+    fullfile('kinsol','KINSol.m')
+    fullfile('kinsol','kim','Contents.m')
+    fullfile('kinsol','kim','kim_bjac.m')
+    fullfile('kinsol','kim','kim_djac.m')
+    fullfile('kinsol','kim','kim_gcom.m')
+    fullfile('kinsol','kim','kim_gloc.m')
+    fullfile('kinsol','kim','kim_info.m')
+    fullfile('kinsol','kim','kim_jtv.m')
+    fullfile('kinsol','kim','kim_pset.m')
+    fullfile('kinsol','kim','kim_psol.m')
+    fullfile('kinsol','kim','kim_sys.m')
+    fullfile('kinsol','kim',kimmex)
+            };
+
+kim_ftypes = {
+    fullfile('kinsol','function_types','KINSysFn.m')
+    fullfile('kinsol','function_types','KINBandJacFn.m')
+    fullfile('kinsol','function_types','KINDenseJacFn.m')
+    fullfile('kinsol','function_types','KINJacTimesVecFn.m')
+    fullfile('kinsol','function_types','KINPrecSetupFn.m')
+    fullfile('kinsol','function_types','KINPrecSolveFn.m')
+    fullfile('kinsol','function_types','KINGcommFn.m')
+    fullfile('kinsol','function_types','KINGlocalFn.m')
+             };
+
+kim_exs = {
+    fullfile('kinsol','examples_ser','mkinDiagon_kry.m')
+    fullfile('kinsol','examples_ser','mkinTest_dns.m')
+    fullfile('kinsol','examples_ser','mkinFerTron_dns.m')
+    fullfile('kinsol','examples_ser','mkinRoboKin_dns.m')
+          };
+
+kim_exp = {
+    fullfile('kinsol','examples_par','mkinDiagon_kry_p.m') 
+          };
+
+stb_files = [kim_files ; kim_ftypes ; kim_exs];
+if par
+  stb_files = [stb_files ; kim_exp];
+end
+
+fprintf('\n\n');
+for i=1:length(stb_files)
+  src = fullfile(stb,stb_files{i});
+  dest = fullfile(stbi,stb_files{i});
+  fprintf('Install %s\n',dest);
+  [success,msg,msgid] = copyfile(src,dest);
+  if ~success
+    disp(msg);
+    break;
+  end
+end
+
+
